# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/target_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/vpc/v1/target_group.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xbb\x01\n\x0bTargetGroup\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1.TargetGroupSpecR\x04spec\x12\x38\n\x06status\x18\x03 \x01(\x0b\x32 .nebius.vpc.v1.TargetGroupStatusR\x06status\"B\n\x0fTargetGroupSpec\x12/\n\x07targets\x18\x01 \x03(\x0b\x32\x15.nebius.vpc.v1.TargetR\x07targets\"f\n\x06Target\x12K\n\x10\x63ompute_instance\x18\x01 \x01(\x0b\x32\x1e.nebius.vpc.v1.ComputeInstanceH\x00R\x0f\x63omputeInstanceB\x0f\n\x06target\x12\x05\xbaH\x02\x08\x01\"e\n\x0f\x43omputeInstance\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12:\n\x16network_interface_name\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\x14networkInterfaceName\"\x85\x01\n\x11TargetGroupStatus\x12*\n\x11load_balancer_ids\x18\x01 \x03(\tR\x0floadBalancerIds\x12\x44\n\x0ftarget_statuses\x18\x02 \x03(\x0b\x32\x1b.nebius.vpc.v1.TargetStatusR\x0etargetStatuses\"\xdd\x01\n\x0cTargetStatus\x12.\n\x13\x63ompute_instance_id\x18\x01 \x01(\tR\x11\x63omputeInstanceId\x12J\n\x0ctarget_state\x18\x02 \x01(\x0e\x32\'.nebius.vpc.v1.TargetStatus.TargetStateR\x0btargetState\"Q\n\x0bTargetState\x12\x1c\n\x18TARGET_STATE_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x42W\n\x14\x61i.nebius.pub.vpc.v1B\x10TargetGroupProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.target_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\020TargetGroupProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _TARGET.oneofs_by_name['target']._options = None
  _TARGET.oneofs_by_name['target']._serialized_options = b'\272H\002\010\001'
  _COMPUTEINSTANCE.fields_by_name['id']._options = None
  _COMPUTEINSTANCE.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _COMPUTEINSTANCE.fields_by_name['network_interface_name']._options = None
  _COMPUTEINSTANCE.fields_by_name['network_interface_name']._serialized_options = b'\272J\001\007'
  _globals['_TARGETGROUP']._serialized_start=140
  _globals['_TARGETGROUP']._serialized_end=327
  _globals['_TARGETGROUPSPEC']._serialized_start=329
  _globals['_TARGETGROUPSPEC']._serialized_end=395
  _globals['_TARGET']._serialized_start=397
  _globals['_TARGET']._serialized_end=499
  _globals['_COMPUTEINSTANCE']._serialized_start=501
  _globals['_COMPUTEINSTANCE']._serialized_end=602
  _globals['_TARGETGROUPSTATUS']._serialized_start=605
  _globals['_TARGETGROUPSTATUS']._serialized_end=738
  _globals['_TARGETSTATUS']._serialized_start=741
  _globals['_TARGETSTATUS']._serialized_end=962
  _globals['_TARGETSTATUS_TARGETSTATE']._serialized_start=881
  _globals['_TARGETSTATUS_TARGETSTATE']._serialized_end=962
# @@protoc_insertion_point(module_scope)
