# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/authentication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.audit.v2 import access_token_pb2 as nebius_dot_audit_dot_v2_dot_access__token__pb2
from nebius.api.nebius.audit.v2 import authentication_type_pb2 as nebius_dot_audit_dot_v2_dot_authentication__type__pb2
from nebius.api.nebius.audit.v2 import federation_pb2 as nebius_dot_audit_dot_v2_dot_federation__pb2
from nebius.api.nebius.audit.v2 import static_key_pb2 as nebius_dot_audit_dot_v2_dot_static__key__pb2
from nebius.api.nebius.audit.v2 import subject_pb2 as nebius_dot_audit_dot_v2_dot_subject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/audit/v2/authentication.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\"nebius/audit/v2/access_token.proto\x1a)nebius/audit/v2/authentication_type.proto\x1a nebius/audit/v2/federation.proto\x1a nebius/audit/v2/static_key.proto\x1a\x1dnebius/audit/v2/subject.proto\"\xb0\x03\n\x0e\x41uthentication\x12,\n\rauthenticated\x18\x01 \x01(\x08\x42\x06\xbaH\x03\xc8\x01\x01R\rauthenticated\x12\x32\n\x07subject\x18\x02 \x01(\x0b\x32\x18.nebius.audit.v2.SubjectR\x07subject\x12;\n\nfederation\x18\x03 \x01(\x0b\x32\x1b.nebius.audit.v2.FederationR\nfederation\x12T\n\x13\x61uthentication_type\x18\x04 \x01(\x0e\x32#.nebius.audit.v2.AuthenticationTypeR\x12\x61uthenticationType\x12I\n\x10token_credential\x18\n \x01(\x0b\x32\x1c.nebius.audit.v2.AccessTokenH\x00R\x0ftokenCredential\x12P\n\x15static_key_credential\x18\x0b \x01(\x0b\x32\x1a.nebius.audit.v2.StaticKeyH\x00R\x13staticKeyCredentialB\x0c\n\ncredentialB^\n\x16\x61i.nebius.pub.audit.v2B\x13\x41uthenticationProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\023AuthenticationProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUTHENTICATION.fields_by_name['authenticated']._options = None
  _AUTHENTICATION.fields_by_name['authenticated']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUTHENTICATION']._serialized_start=265
  _globals['_AUTHENTICATION']._serialized_end=697
# @@protoc_insertion_point(module_scope)
