# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/msp/v1alpha1/common.proto\x12\x13nebius.msp.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\"$\n\nGetRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"S\n\x10GetByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\'\n\rDeleteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"&\n\x0cStartRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"%\n\x0bStopRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"w\n\x0bListRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12$\n\tpage_size\x18\x02 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"P\n\x14UpdateVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12 \n\x07version\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07versionB^\n\x1a\x61i.nebius.pub.msp.v1alpha1B\x0b\x43ommonProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.msp.v1alpha1B\013CommonProtoP\001Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1'
  _GETREQUEST.fields_by_name['id']._options = None
  _GETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _DELETEREQUEST.fields_by_name['id']._options = None
  _DELETEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _STARTREQUEST.fields_by_name['id']._options = None
  _STARTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _STOPREQUEST.fields_by_name['id']._options = None
  _STOPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTREQUEST.fields_by_name['parent_id']._options = None
  _LISTREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTREQUEST.fields_by_name['page_size']._options = None
  _LISTREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\004\"\002(\000'
  _UPDATEVERSIONREQUEST.fields_by_name['id']._options = None
  _UPDATEVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEVERSIONREQUEST.fields_by_name['version']._options = None
  _UPDATEVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETREQUEST']._serialized_start=86
  _globals['_GETREQUEST']._serialized_end=122
  _globals['_GETBYNAMEREQUEST']._serialized_start=124
  _globals['_GETBYNAMEREQUEST']._serialized_end=207
  _globals['_DELETEREQUEST']._serialized_start=209
  _globals['_DELETEREQUEST']._serialized_end=248
  _globals['_STARTREQUEST']._serialized_start=250
  _globals['_STARTREQUEST']._serialized_end=288
  _globals['_STOPREQUEST']._serialized_start=290
  _globals['_STOPREQUEST']._serialized_end=327
  _globals['_LISTREQUEST']._serialized_start=329
  _globals['_LISTREQUEST']._serialized_end=448
  _globals['_UPDATEVERSIONREQUEST']._serialized_start=450
  _globals['_UPDATEVERSIONREQUEST']._serialized_end=530
# @@protoc_insertion_point(module_scope)
