# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/secret_version_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.mysterybox.v1 import secret_version_pb2 as nebius_dot_mysterybox_dot_v1_dot_secret__version__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1nebius/mysterybox/v1/secret_version_service.proto\x12\x14nebius.mysterybox.v1\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1b\x62uf/validate/validate.proto\x1a)nebius/mysterybox/v1/secret_version.proto\x1a\x18nebius/annotations.proto\"\x99\x01\n\x1a\x43reateSecretVersionRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.mysterybox.v1.SecretVersionSpecR\x04spec\"p\n\x17GetSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12=\n\x1bshow_scheduled_for_deletion\x18\x02 \x01(\x08R\x18showScheduledForDeletion\"\xca\x01\n\x19ListSecretVersionsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12*\n\tpage_size\x18\x02 \x01(\x03\x42\r\xbaH\n\xd8\x01\x01\"\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12=\n\x1bshow_scheduled_for_deletion\x18\x04 \x01(\x08R\x18showScheduledForDeletion\"\x7f\n\x1aListSecretVersionsResponse\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x39\n\x05items\x18\x03 \x03(\x0b\x32#.nebius.mysterybox.v1.SecretVersionR\x05items\"4\n\x1a\x44\x65leteSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"6\n\x1cUndeleteSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xfe\x03\n\x14SecretVersionService\x12W\n\x06\x43reate\x12\x30.nebius.mysterybox.v1.CreateSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x12Y\n\x03Get\x12-.nebius.mysterybox.v1.GetSecretVersionRequest\x1a#.nebius.mysterybox.v1.SecretVersion\x12i\n\x04List\x12/.nebius.mysterybox.v1.ListSecretVersionsRequest\x1a\x30.nebius.mysterybox.v1.ListSecretVersionsResponse\x12W\n\x06\x44\x65lete\x12\x30.nebius.mysterybox.v1.DeleteSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x12[\n\x08Undelete\x12\x32.nebius.mysterybox.v1.UndeleteSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x11\xbaJ\x0e\x63pl.mysteryboxBn\n\x1b\x61i.nebius.pub.mysterybox.v1B\x19SecretVersionServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.secret_version_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\031SecretVersionServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _GETSECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _GETSECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSECRETVERSIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTSECRETVERSIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSECRETVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\n\330\001\001\"\005\030\350\007(\000'
  _DELETESECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _DELETESECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UNDELETESECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _UNDELETESECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _SECRETVERSIONSERVICE._options = None
  _SECRETVERSIONSERVICE._serialized_options = b'\272J\016cpl.mysterybox'
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_start=241
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_end=394
  _globals['_GETSECRETVERSIONREQUEST']._serialized_start=396
  _globals['_GETSECRETVERSIONREQUEST']._serialized_end=508
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_start=511
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_end=713
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_start=715
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_end=842
  _globals['_DELETESECRETVERSIONREQUEST']._serialized_start=844
  _globals['_DELETESECRETVERSIONREQUEST']._serialized_end=896
  _globals['_UNDELETESECRETVERSIONREQUEST']._serialized_start=898
  _globals['_UNDELETESECRETVERSIONREQUEST']._serialized_end=952
  _globals['_SECRETVERSIONSERVICE']._serialized_start=955
  _globals['_SECRETVERSIONSERVICE']._serialized_end=1465
# @@protoc_insertion_point(module_scope)
