# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/registry/v1/artifact_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.registry.v1 import artifact_pb2 as nebius_dot_registry_dot_v1_dot_artifact__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/registry/v1/artifact_service.proto\x12\x12nebius.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a nebius/common/v1/operation.proto\x1a!nebius/registry/v1/artifact.proto\",\n\x12GetArtifactRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x87\x01\n\x14ListArtifactsRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"s\n\x15ListArtifactsResponse\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32\x1c.nebius.registry.v1.ArtifactR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"/\n\x15\x44\x65leteArtifactRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\x9a\x02\n\x0f\x41rtifactService\x12K\n\x03Get\x12&.nebius.registry.v1.GetArtifactRequest\x1a\x1c.nebius.registry.v1.Artifact\x12[\n\x04List\x12(.nebius.registry.v1.ListArtifactsRequest\x1a).nebius.registry.v1.ListArtifactsResponse\x12P\n\x06\x44\x65lete\x12).nebius.registry.v1.DeleteArtifactRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x0b\xbaJ\x08registryBe\n\x19\x61i.nebius.pub.registry.v1B\x14\x41rtifactServiceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/registry/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.registry.v1.artifact_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.registry.v1B\024ArtifactServiceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/registry/v1'
  _GETARTIFACTREQUEST.fields_by_name['id']._options = None
  _GETARTIFACTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEARTIFACTREQUEST.fields_by_name['id']._options = None
  _DELETEARTIFACTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ARTIFACTSERVICE._options = None
  _ARTIFACTSERVICE._serialized_options = b'\272J\010registry'
  _globals['_GETARTIFACTREQUEST']._serialized_start=189
  _globals['_GETARTIFACTREQUEST']._serialized_end=233
  _globals['_LISTARTIFACTSREQUEST']._serialized_start=236
  _globals['_LISTARTIFACTSREQUEST']._serialized_end=371
  _globals['_LISTARTIFACTSRESPONSE']._serialized_start=373
  _globals['_LISTARTIFACTSRESPONSE']._serialized_end=488
  _globals['_DELETEARTIFACTREQUEST']._serialized_start=490
  _globals['_DELETEARTIFACTREQUEST']._serialized_end=537
  _globals['_ARTIFACTSERVICE']._serialized_start=540
  _globals['_ARTIFACTSERVICE']._serialized_end=822
# @@protoc_insertion_point(module_scope)
