# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/registry/v1/artifact.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/registry/v1/artifact.proto\x12\x12nebius.registry.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x08\x41rtifact\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nmedia_type\x18\x03 \x01(\tR\tmediaType\x12\x16\n\x06\x64igest\x18\x04 \x01(\tR\x06\x64igest\x12\x12\n\x04size\x18\x05 \x01(\x03R\x04size\x12;\n\x06status\x18\x06 \x01(\x0e\x32#.nebius.registry.v1.Artifact.StatusR\x06status\x12\x35\n\x04type\x18\x07 \x01(\x0e\x32!.nebius.registry.v1.Artifact.TypeR\x04type\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\":\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\"\x83\x01\n\x04Type\x12\x08\n\x04\x42LOB\x10\x00\x12\x0c\n\x08MANIFEST\x10\x01\x12\x0f\n\x0b\x44\x45\x42_PACKAGE\x10\x02\x12\x11\n\rMANIFEST_LIST\x10\x03\x12\x11\n\rRELEASE_INDEX\x10\x04\x12\x11\n\rPACKAGE_INDEX\x10\x05\x12\x19\n\x15GZIPPED_PACKAGE_INDEX\x10\x06\x42^\n\x19\x61i.nebius.pub.registry.v1B\rArtifactProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/registry/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.registry.v1.artifact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.registry.v1B\rArtifactProtoP\001Z0github.com/nebius/gosdk/proto/nebius/registry/v1'
  _globals['_ARTIFACT']._serialized_start=91
  _globals['_ARTIFACT']._serialized_end=660
  _globals['_ARTIFACT_STATUS']._serialized_start=468
  _globals['_ARTIFACT_STATUS']._serialized_end=526
  _globals['_ARTIFACT_TYPE']._serialized_start=529
  _globals['_ARTIFACT_TYPE']._serialized_end=660
# @@protoc_insertion_point(module_scope)
