# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/authorization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#nebius/audit/v2/authorization.proto\x12\x0fnebius.audit.v2\"/\n\rAuthorization\x12\x1e\n\nauthorized\x18\x01 \x01(\x08R\nauthorizedB]\n\x16\x61i.nebius.pub.audit.v2B\x12\x41uthorizationProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.authorization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\022AuthorizationProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_AUTHORIZATION']._serialized_start=56
  _globals['_AUTHORIZATION']._serialized_end=103
# @@protoc_insertion_point(module_scope)
