# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/storage/v1/bucket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.storage.v1 import base_pb2 as nebius_dot_storage_dot_v1_dot_base__pb2
from nebius.api.nebius.storage.v1 import bucket_counters_pb2 as nebius_dot_storage_dot_v1_dot_bucket__counters__pb2
from nebius.api.nebius.storage.v1 import lifecycle_pb2 as nebius_dot_storage_dot_v1_dot_lifecycle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/storage/v1/bucket.proto\x12\x11nebius.storage.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1cnebius/storage/v1/base.proto\x1a\'nebius/storage/v1/bucket_counters.proto\x1a!nebius/storage/v1/lifecycle.proto\"\xd0\x01\n\x06\x42ucket\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.storage.v1.BucketSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12=\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.storage.v1.BucketStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x03\"\x9e\x04\n\nBucketSpec\x12V\n\x11versioning_policy\x18\x02 \x01(\x0e\x32#.nebius.storage.v1.VersioningPolicyB\x04\xbaJ\x01\x07R\x10versioningPolicy\x12$\n\x0emax_size_bytes\x18\x04 \x01(\x03R\x0cmaxSizeBytes\x12\x62\n\x17lifecycle_configuration\x18\x05 \x01(\x0b\x32).nebius.storage.v1.LifecycleConfigurationR\x16lifecycleConfiguration\x12S\n\x15\x64\x65\x66\x61ult_storage_class\x18\t \x01(\x0e\x32\x1f.nebius.storage.v1.StorageClassR\x13\x64\x65\x66\x61ultStorageClass\x12\xa8\x01\n\x16override_storage_class\x18\n \x01(\x0e\x32\x1f.nebius.storage.v1.StorageClassBQ\x18\x01\xd2JL\n\n2025-12-01\x12>Use `default_storage_class` with `force_storage_class` insteadR\x14overrideStorageClass\x12.\n\x13\x66orce_storage_class\x18\x0b \x01(\x08R\x11\x66orceStorageClass\"\xcc\x04\n\x0c\x42ucketStatus\x12=\n\x08\x63ounters\x18\x01 \x03(\x0b\x32!.nebius.storage.v1.BucketCountersR\x08\x63ounters\x12;\n\x05state\x18\x02 \x01(\x0e\x32%.nebius.storage.v1.BucketStatus.StateR\x05state\x12Z\n\x10suspension_state\x18\x03 \x01(\x0e\x32/.nebius.storage.v1.BucketStatus.SuspensionStateR\x0fsuspensionState\x12\x39\n\ndeleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\x12\x35\n\x08purge_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07purgeAt\x12\x1f\n\x0b\x64omain_name\x18\x06 \x01(\tR\ndomainName\x12\x16\n\x06region\x18\x08 \x01(\tR\x06region\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x1a\n\x16SCHEDULED_FOR_DELETION\x10\x04\"U\n\x0fSuspensionState\x12 \n\x1cSUSPENSION_STATE_UNSPECIFIED\x10\x00\x12\x11\n\rNOT_SUSPENDED\x10\x01\x12\r\n\tSUSPENDED\x10\x02\x42Z\n\x18\x61i.nebius.pub.storage.v1B\x0b\x42ucketProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/storage/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.storage.v1.bucket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.storage.v1B\013BucketProtoP\001Z/github.com/nebius/gosdk/proto/nebius/storage/v1'
  _BUCKET.fields_by_name['metadata']._options = None
  _BUCKET.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _BUCKET.fields_by_name['spec']._options = None
  _BUCKET.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _BUCKET.fields_by_name['status']._options = None
  _BUCKET.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _BUCKET._options = None
  _BUCKET._serialized_options = b'\272J\001\003'
  _BUCKETSPEC.fields_by_name['versioning_policy']._options = None
  _BUCKETSPEC.fields_by_name['versioning_policy']._serialized_options = b'\272J\001\007'
  _BUCKETSPEC.fields_by_name['override_storage_class']._options = None
  _BUCKETSPEC.fields_by_name['override_storage_class']._serialized_options = b'\030\001\322JL\n\n2025-12-01\022>Use `default_storage_class` with `force_storage_class` instead'
  _globals['_BUCKET']._serialized_start=281
  _globals['_BUCKET']._serialized_end=489
  _globals['_BUCKETSPEC']._serialized_start=492
  _globals['_BUCKETSPEC']._serialized_end=1034
  _globals['_BUCKETSTATUS']._serialized_start=1037
  _globals['_BUCKETSTATUS']._serialized_end=1625
  _globals['_BUCKETSTATUS_STATE']._serialized_start=1440
  _globals['_BUCKETSTATUS_STATE']._serialized_end=1538
  _globals['_BUCKETSTATUS_SUSPENSIONSTATE']._serialized_start=1540
  _globals['_BUCKETSTATUS_SUSPENSIONSTATE']._serialized_end=1625
# @@protoc_insertion_point(module_scope)
