# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/v1/resource_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%nebius/common/v1/resource_event.proto\x12\x10nebius.common.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x18nebius/annotations.proto\"\xcb\x02\n\rResourceEvent\x12\x43\n\x0boccurred_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\noccurredAt\x12\x43\n\x05level\x18\x02 \x01(\x0e\x32%.nebius.common.v1.ResourceEvent.LevelB\x06\xbaH\x03\xc8\x01\x01R\x05level\x12\x1a\n\x04\x63ode\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04\x63ode\x12 \n\x07message\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07message\x12.\n\x05\x65rror\x18\n \x01(\x0b\x32\x12.google.rpc.StatusB\x04\xbaJ\x01\x06R\x05\x65rror\"B\n\x05Level\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x08\n\x04WARN\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"\xee\x01\n\x16RecurrentResourceEvent\x12N\n\x11\x66irst_occurred_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0f\x66irstOccurredAt\x12P\n\x0flast_occurrence\x18\x02 \x01(\x0b\x32\x1f.nebius.common.v1.ResourceEventB\x06\xbaH\x03\xc8\x01\x01R\x0elastOccurrence\x12\x32\n\x10occurrence_count\x18\x03 \x01(\x03\x42\x07\xbaH\x04\"\x02 \x00R\x0foccurrenceCountB_\n\x17\x61i.nebius.pub.common.v1B\x12ResourceEventProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.v1.resource_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.common.v1B\022ResourceEventProtoP\001Z.github.com/nebius/gosdk/proto/nebius/common/v1'
  _RESOURCEEVENT.fields_by_name['occurred_at']._options = None
  _RESOURCEEVENT.fields_by_name['occurred_at']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCEEVENT.fields_by_name['level']._options = None
  _RESOURCEEVENT.fields_by_name['level']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCEEVENT.fields_by_name['code']._options = None
  _RESOURCEEVENT.fields_by_name['code']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCEEVENT.fields_by_name['message']._options = None
  _RESOURCEEVENT.fields_by_name['message']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCEEVENT.fields_by_name['error']._options = None
  _RESOURCEEVENT.fields_by_name['error']._serialized_options = b'\272J\001\006'
  _RECURRENTRESOURCEEVENT.fields_by_name['first_occurred_at']._options = None
  _RECURRENTRESOURCEEVENT.fields_by_name['first_occurred_at']._serialized_options = b'\272H\003\310\001\001'
  _RECURRENTRESOURCEEVENT.fields_by_name['last_occurrence']._options = None
  _RECURRENTRESOURCEEVENT.fields_by_name['last_occurrence']._serialized_options = b'\272H\003\310\001\001'
  _RECURRENTRESOURCEEVENT.fields_by_name['occurrence_count']._options = None
  _RECURRENTRESOURCEEVENT.fields_by_name['occurrence_count']._serialized_options = b'\272H\004\"\002 \000'
  _globals['_RESOURCEEVENT']._serialized_start=173
  _globals['_RESOURCEEVENT']._serialized_end=504
  _globals['_RESOURCEEVENT_LEVEL']._serialized_start=438
  _globals['_RESOURCEEVENT_LEVEL']._serialized_end=504
  _globals['_RECURRENTRESOURCEEVENT']._serialized_start=507
  _globals['_RECURRENTRESOURCEEVENT']._serialized_end=745
# @@protoc_insertion_point(module_scope)
