# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/dns/v1/zone.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18nebius/dns/v1/zone.proto\x12\rnebius.dns.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xa6\x01\n\x04Zone\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x17.nebius.dns.v1.ZoneSpecR\x04spec\x12\x31\n\x06status\x18\x03 \x01(\x0b\x32\x19.nebius.dns.v1.ZoneStatusR\x06status\"\xd6\x02\n\x08ZoneSpec\x12\xd5\x01\n\x0b\x64omain_name\x18\x01 \x01(\tB\xb3\x01\xbaH\xaf\x01\xba\x01\xa8\x01\n\x12\x64omain_name_format\x12Tdomain_name must be a fully-qualified domain name with \'.\' at the end, e.g. \'x.y.z.\'\x1a<size(this) < 253 && this.matches(\'^[a-z0-9][-a-z0-9.]*[.]$\')\xc8\x01\x01R\ndomainName\x12/\n\x03vpc\x18\x0c \x01(\x0b\x32\x1b.nebius.dns.v1.VpcZoneScopeH\x00R\x03vpc\x12\x31\n\x08soa_spec\x18\x1e \x01(\x0b\x32\x16.nebius.dns.v1.SoaSpecR\x07soaSpecB\x0e\n\x05scope\x12\x05\xbaH\x02\x08\x01\"H\n\x0cVpcZoneScope\x12\x38\n\x12primary_network_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x10primaryNetworkId\",\n\x07SoaSpec\x12!\n\x0cnegative_ttl\x18\x1e \x01(\x03R\x0bnegativeTtl\"Q\n\nZoneStatus\x12!\n\x0crecord_count\x18\x14 \x01(\x03R\x0brecordCount\x12 \n\x0breconciling\x18\x64 \x01(\x08R\x0breconciling\"\\\n\x0eGetZoneRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x32\n\x10resource_version\x18\x02 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x0fresourceVersion\"s\n\x10ListZonesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"f\n\x11ListZonesResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x13.nebius.dns.v1.ZoneR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageTokenBP\n\x14\x61i.nebius.pub.dns.v1B\tZoneProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/dns/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.dns.v1.zone_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.dns.v1B\tZoneProtoP\001Z+github.com/nebius/gosdk/proto/nebius/dns/v1'
  _ZONESPEC.oneofs_by_name['scope']._options = None
  _ZONESPEC.oneofs_by_name['scope']._serialized_options = b'\272H\002\010\001'
  _ZONESPEC.fields_by_name['domain_name']._options = None
  _ZONESPEC.fields_by_name['domain_name']._serialized_options = b'\272H\257\001\272\001\250\001\n\022domain_name_format\022Tdomain_name must be a fully-qualified domain name with \'.\' at the end, e.g. \'x.y.z.\'\032<size(this) < 253 && this.matches(\'^[a-z0-9][-a-z0-9.]*[.]$\')\310\001\001'
  _VPCZONESCOPE.fields_by_name['primary_network_id']._options = None
  _VPCZONESCOPE.fields_by_name['primary_network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _GETZONEREQUEST.fields_by_name['id']._options = None
  _GETZONEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETZONEREQUEST.fields_by_name['resource_version']._options = None
  _GETZONEREQUEST.fields_by_name['resource_version']._serialized_options = b'\272H\004\"\002(\000'
  _LISTZONESREQUEST.fields_by_name['parent_id']._options = None
  _LISTZONESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ZONE']._serialized_start=132
  _globals['_ZONE']._serialized_end=298
  _globals['_ZONESPEC']._serialized_start=301
  _globals['_ZONESPEC']._serialized_end=643
  _globals['_VPCZONESCOPE']._serialized_start=645
  _globals['_VPCZONESCOPE']._serialized_end=717
  _globals['_SOASPEC']._serialized_start=719
  _globals['_SOASPEC']._serialized_end=763
  _globals['_ZONESTATUS']._serialized_start=765
  _globals['_ZONESTATUS']._serialized_end=846
  _globals['_GETZONEREQUEST']._serialized_start=848
  _globals['_GETZONEREQUEST']._serialized_end=940
  _globals['_LISTZONESREQUEST']._serialized_start=942
  _globals['_LISTZONESREQUEST']._serialized_end=1057
  _globals['_LISTZONESRESPONSE']._serialized_start=1059
  _globals['_LISTZONESRESPONSE']._serialized_end=1161
# @@protoc_insertion_point(module_scope)
