# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import access_key_pb2 as nebius_dot_iam_dot_v1_dot_access__key__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v1/access_key_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v1/access_key.proto\x1a\x1anebius/iam/v1/access.proto\"\x8a\x01\n\x16\x43reateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.AccessKeySpecR\x04spec\"X\n\x0bKeyIdentity\x12\x10\n\x02id\x18\x01 \x01(\tH\x00R\x02id\x12+\n\x11\x61ws_access_key_id\x18\x02 \x01(\tH\x00R\x0e\x61wsAccessKeyIdB\n\n\x08identity\"/\n\x1dGetAccessKeySecretOnceRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetAccessKeyByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"G\n\x1aGetAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"\x9b\x01\n\x15ListAccessKeysRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\xa6\x01\n\x1eListAccessKeysByAccountRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountR\x07\x61\x63\x63ount\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x8a\x01\n\x16UpdateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.AccessKeySpecR\x04spec\"F\n\x18\x41\x63tivateAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"H\n\x1a\x44\x65\x61\x63tivateAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"D\n\x16\x44\x65leteAccessKeyRequest\x12*\n\x02id\x18\x01 \x01(\x0b\x32\x1a.nebius.iam.v1.KeyIdentityR\x02id\"=\n\x1eGetAccessKeySecretOnceResponse\x12\x1b\n\x06secret\x18\x01 \x01(\tB\x03\xc0J\x01R\x06secret\"p\n\x16ListAccessKeysResponse\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x18.nebius.iam.v1.AccessKeyR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xfc\x07\n\x10\x41\x63\x63\x65ssKeyService\x12L\n\x06\x43reate\x12%.nebius.iam.v1.CreateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12S\n\x04List\x12$.nebius.iam.v1.ListAccessKeysRequest\x1a%.nebius.iam.v1.ListAccessKeysResponse\x12\x65\n\rListByAccount\x12-.nebius.iam.v1.ListAccessKeysByAccountRequest\x1a%.nebius.iam.v1.ListAccessKeysResponse\x12L\n\x06Update\x12%.nebius.iam.v1.UpdateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x07GetById\x12&.nebius.iam.v1.GetAccessKeyByIdRequest\x1a\x18.nebius.iam.v1.AccessKey\x12Q\n\nGetByAwsId\x12).nebius.iam.v1.GetAccessKeyByAwsIdRequest\x1a\x18.nebius.iam.v1.AccessKey\x12l\n\rGetSecretOnce\x12,.nebius.iam.v1.GetAccessKeySecretOnceRequest\x1a-.nebius.iam.v1.GetAccessKeySecretOnceResponse\x12P\n\x08\x41\x63tivate\x12\'.nebius.iam.v1.ActivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12T\n\nDeactivate\x12).nebius.iam.v1.DeactivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12L\n\x06\x44\x65lete\x12%.nebius.iam.v1.DeleteAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x8b\x01\x88\x02\x01\xbaJ\x07\x63pl.iam\xd2J{\n\n2026-09-01\x12mAccess keys API v1 is deprecated, use the v2 version instead. Keys produced by API v1 are available using v2.B\\\n\x14\x61i.nebius.pub.iam.v1B\x15\x41\x63\x63\x65ssKeyServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.access_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\025AccessKeyServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETACCESSKEYSECRETONCERESPONSE.fields_by_name['secret']._options = None
  _GETACCESSKEYSECRETONCERESPONSE.fields_by_name['secret']._serialized_options = b'\300J\001'
  _ACCESSKEYSERVICE._options = None
  _ACCESSKEYSERVICE._serialized_options = b'\210\002\001\272J\007cpl.iam\322J{\n\n2026-09-01\022mAccess keys API v1 is deprecated, use the v2 version instead. Keys produced by API v1 are available using v2.'
  _globals['_CREATEACCESSKEYREQUEST']._serialized_start=211
  _globals['_CREATEACCESSKEYREQUEST']._serialized_end=349
  _globals['_KEYIDENTITY']._serialized_start=351
  _globals['_KEYIDENTITY']._serialized_end=439
  _globals['_GETACCESSKEYSECRETONCEREQUEST']._serialized_start=441
  _globals['_GETACCESSKEYSECRETONCEREQUEST']._serialized_end=488
  _globals['_GETACCESSKEYBYIDREQUEST']._serialized_start=490
  _globals['_GETACCESSKEYBYIDREQUEST']._serialized_end=531
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_start=533
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_end=604
  _globals['_LISTACCESSKEYSREQUEST']._serialized_start=607
  _globals['_LISTACCESSKEYSREQUEST']._serialized_end=762
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_start=765
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_end=931
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_start=934
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_end=1072
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_start=1074
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_end=1144
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_start=1146
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_end=1218
  _globals['_DELETEACCESSKEYREQUEST']._serialized_start=1220
  _globals['_DELETEACCESSKEYREQUEST']._serialized_end=1288
  _globals['_GETACCESSKEYSECRETONCERESPONSE']._serialized_start=1290
  _globals['_GETACCESSKEYSECRETONCERESPONSE']._serialized_end=1351
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_start=1353
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_end=1465
  _globals['_ACCESSKEYSERVICE']._serialized_start=1468
  _globals['_ACCESSKEYSERVICE']._serialized_end=2488
# @@protoc_insertion_point(module_scope)
