# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import static_key_pb2 as nebius_dot_iam_dot_v1_dot_static__key__pb2
from nebius.api.nebius.iam.v1 import static_key_service_pb2 as nebius_dot_iam_dot_v1_dot_static__key__service__pb2


class StaticKeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Issue = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Issue',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/List',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Get',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/GetByName',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Find = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Find',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.FromString,
                )
        self.Revoke = channel.unary_unary(
                '/nebius.iam.v1.StaticKeyService/Revoke',
                request_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class StaticKeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Issue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Revoke(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StaticKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Issue': grpc.unary_unary_rpc_method_handler(
                    servicer.Issue,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.SerializeToString,
            ),
            'Revoke': grpc.unary_unary_rpc_method_handler(
                    servicer.Revoke,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.StaticKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StaticKeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Issue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Issue',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.IssueStaticKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/List',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.ListStaticKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Get',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/GetByName',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.GetStaticKeyByNameRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__pb2.StaticKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Delete',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.DeleteStaticKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Find',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.FindStaticKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Revoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.StaticKeyService/Revoke',
            nebius_dot_iam_dot_v1_dot_static__key__service__pb2.RevokeStaticKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
