# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``buf.validate``"""

#@ local imports here @#

# file: buf/validate/validate.proto
# file skipped
__all__ = [
    #@ local import names here @#
    "Ignore",
    "KnownRegex",
    "message",
    "oneof",
    "field",
    "predefined",
    "Constraint",
    "MessageConstraints",
    "OneofConstraints",
    "FieldConstraints",
    "PredefinedConstraints",
    "FloatRules",
    "DoubleRules",
    "Int32Rules",
    "Int64Rules",
    "UInt32Rules",
    "UInt64Rules",
    "SInt32Rules",
    "SInt64Rules",
    "Fixed32Rules",
    "Fixed64Rules",
    "SFixed32Rules",
    "SFixed64Rules",
    "BoolRules",
    "StringRules",
    "BytesRules",
    "EnumRules",
    "RepeatedRules",
    "MapRules",
    "AnyRules",
    "DurationRules",
    "TimestampRules",
    "Violations",
    "Violation",
    "FieldPath",
    "FieldPathElement",
]
