# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/service_account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#nebius/iam/v1/service_account.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xda\x01\n\x0eServiceAccount\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12=\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.iam.v1.ServiceAccountSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x41\n\x06status\x18\x03 \x01(\x0b\x32#.nebius.iam.v1.ServiceAccountStatusB\x04\xbaJ\x01\x05R\x06status\"6\n\x12ServiceAccountSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\".\n\x14ServiceAccountStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\"P\n\x18ServiceAccountAttributes\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scriptionBZ\n\x14\x61i.nebius.pub.iam.v1B\x13ServiceAccountProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.service_account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\023ServiceAccountProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _SERVICEACCOUNT.fields_by_name['metadata']._options = None
  _SERVICEACCOUNT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _SERVICEACCOUNT.fields_by_name['spec']._options = None
  _SERVICEACCOUNT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _SERVICEACCOUNT.fields_by_name['status']._options = None
  _SERVICEACCOUNT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _globals['_SERVICEACCOUNT']._serialized_start=143
  _globals['_SERVICEACCOUNT']._serialized_end=361
  _globals['_SERVICEACCOUNTSPEC']._serialized_start=363
  _globals['_SERVICEACCOUNTSPEC']._serialized_end=417
  _globals['_SERVICEACCOUNTSTATUS']._serialized_start=419
  _globals['_SERVICEACCOUNTSTATUS']._serialized_end=465
  _globals['_SERVICEACCOUNTATTRIBUTES']._serialized_start=467
  _globals['_SERVICEACCOUNTATTRIBUTES']._serialized_end=547
# @@protoc_insertion_point(module_scope)
