# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/group_membership_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import group_membership_pb2 as nebius_dot_iam_dot_v1_dot_group__membership__pb2
from nebius.api.nebius.iam.v1 import group_pb2 as nebius_dot_iam_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/iam/v1/group_membership_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a$nebius/iam/v1/group_membership.proto\x1a\x19nebius/iam/v1/group.proto\"\xcc\x01\n\x1c\x43reateGroupMembershipRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32\".nebius.iam.v1.GroupMembershipSpecR\x04spec\x12,\n\x12revoke_after_hours\x18\x04 \x01(\x03R\x10revokeAfterHours\"6\n\x1c\x44\x65leteGroupMembershipRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"3\n\x19GetGroupMembershipRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xa9\x01\n\x1bListGroupMembershipsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\xa3\x01\n\x13ListMemberOfRequest\x12%\n\nsubject_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tsubjectId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"\x88\x01\n\x1cListGroupMembershipsResponse\x12@\n\x0bmemberships\x18\x01 \x03(\x0b\x32\x1e.nebius.iam.v1.GroupMembershipR\x0bmemberships\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xa4\x01\n*ListGroupMembershipsWithAttributesResponse\x12N\n\x0bmemberships\x18\x01 \x03(\x0b\x32,.nebius.iam.v1.GroupMembershipWithAttributesR\x0bmemberships\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"j\n\x14ListMemberOfResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.iam.v1.GroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xd0\x05\n\x16GroupMembershipService\x12R\n\x06\x43reate\x12+.nebius.iam.v1.CreateGroupMembershipRequest\x1a\x1b.nebius.common.v1.Operation\x12O\n\x03Get\x12(.nebius.iam.v1.GetGroupMembershipRequest\x1a\x1e.nebius.iam.v1.GroupMembership\x12k\n\x11GetWithAttributes\x12(.nebius.iam.v1.GetGroupMembershipRequest\x1a,.nebius.iam.v1.GroupMembershipWithAttributes\x12R\n\x06\x44\x65lete\x12+.nebius.iam.v1.DeleteGroupMembershipRequest\x1a\x1b.nebius.common.v1.Operation\x12\x66\n\x0bListMembers\x12*.nebius.iam.v1.ListGroupMembershipsRequest\x1a+.nebius.iam.v1.ListGroupMembershipsResponse\x12\x82\x01\n\x19ListMembersWithAttributes\x12*.nebius.iam.v1.ListGroupMembershipsRequest\x1a\x39.nebius.iam.v1.ListGroupMembershipsWithAttributesResponse\x12W\n\x0cListMemberOf\x12\".nebius.iam.v1.ListMemberOfRequest\x1a#.nebius.iam.v1.ListMemberOfResponse\x1a\n\xbaJ\x07\x63pl.iamBb\n\x14\x61i.nebius.pub.iam.v1B\x1bGroupMembershipServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.group_membership_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\033GroupMembershipServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _CREATEGROUPMEMBERSHIPREQUEST.fields_by_name['metadata']._options = None
  _CREATEGROUPMEMBERSHIPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETEGROUPMEMBERSHIPREQUEST.fields_by_name['id']._options = None
  _DELETEGROUPMEMBERSHIPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPMEMBERSHIPREQUEST.fields_by_name['id']._options = None
  _GETGROUPMEMBERSHIPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTGROUPMEMBERSHIPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTGROUPMEMBERSHIPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTMEMBEROFREQUEST.fields_by_name['subject_id']._options = None
  _LISTMEMBEROFREQUEST.fields_by_name['subject_id']._serialized_options = b'\272H\003\310\001\001'
  _GROUPMEMBERSHIPSERVICE._options = None
  _GROUPMEMBERSHIPSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEGROUPMEMBERSHIPREQUEST']._serialized_start=251
  _globals['_CREATEGROUPMEMBERSHIPREQUEST']._serialized_end=455
  _globals['_DELETEGROUPMEMBERSHIPREQUEST']._serialized_start=457
  _globals['_DELETEGROUPMEMBERSHIPREQUEST']._serialized_end=511
  _globals['_GETGROUPMEMBERSHIPREQUEST']._serialized_start=513
  _globals['_GETGROUPMEMBERSHIPREQUEST']._serialized_end=564
  _globals['_LISTGROUPMEMBERSHIPSREQUEST']._serialized_start=567
  _globals['_LISTGROUPMEMBERSHIPSREQUEST']._serialized_end=736
  _globals['_LISTMEMBEROFREQUEST']._serialized_start=739
  _globals['_LISTMEMBEROFREQUEST']._serialized_end=902
  _globals['_LISTGROUPMEMBERSHIPSRESPONSE']._serialized_start=905
  _globals['_LISTGROUPMEMBERSHIPSRESPONSE']._serialized_end=1041
  _globals['_LISTGROUPMEMBERSHIPSWITHATTRIBUTESRESPONSE']._serialized_start=1044
  _globals['_LISTGROUPMEMBERSHIPSWITHATTRIBUTESRESPONSE']._serialized_end=1208
  _globals['_LISTMEMBEROFRESPONSE']._serialized_start=1210
  _globals['_LISTMEMBEROFRESPONSE']._serialized_end=1316
  _globals['_GROUPMEMBERSHIPSERVICE']._serialized_start=1319
  _globals['_GROUPMEMBERSHIPSERVICE']._serialized_end=2039
# @@protoc_insertion_point(module_scope)
