# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/applications/v1alpha1/k8s_release.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nebius/applications/v1alpha1/k8s_release.proto\x12\x1cnebius.applications.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xf2\x01\n\nK8sRelease\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12L\n\x06status\x18\x03 \x01(\x0b\x32..nebius.applications.v1alpha1.K8sReleaseStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xf6\x02\n\x0eK8sReleaseSpec\x12)\n\ncluster_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tclusterId\x12-\n\x0cproduct_slug\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x0bproductSlug\x12(\n\tnamespace\x18\x03 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnamespace\x12\x35\n\x10\x61pplication_name\x18\x04 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x0f\x61pplicationName\x12\x1f\n\x06values\x18\x05 \x01(\tB\x07\xbaJ\x01\x04\xc0J\x01R\x06values\x12P\n\x03set\x18\x06 \x03(\x0b\x32\x35.nebius.applications.v1alpha1.K8sReleaseSpec.SetEntryB\x07\xbaJ\x01\x04\xc0J\x01R\x03set\x1a\x36\n\x08SetEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe1\x01\n\x10K8sReleaseStatus\x12J\n\x05state\x18\x01 \x01(\x0e\x32\x34.nebius.applications.v1alpha1.K8sReleaseStatus.StateR\x05state\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\\\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08\x44\x45PLOYED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0e\n\nINSTALLING\x10\x05\x42t\n#ai.nebius.pub.applications.v1alpha1B\x0fK8SReleaseProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.applications.v1alpha1.k8s_release_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.applications.v1alpha1B\017K8SReleaseProtoP\001Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1'
  _K8SRELEASE.fields_by_name['metadata']._options = None
  _K8SRELEASE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASE.fields_by_name['spec']._options = None
  _K8SRELEASE.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASE.fields_by_name['status']._options = None
  _K8SRELEASE.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _K8SRELEASE._options = None
  _K8SRELEASE._serialized_options = b'\272J\001\002'
  _K8SRELEASESPEC_SETENTRY._options = None
  _K8SRELEASESPEC_SETENTRY._serialized_options = b'8\001'
  _K8SRELEASESPEC.fields_by_name['cluster_id']._options = None
  _K8SRELEASESPEC.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['product_slug']._options = None
  _K8SRELEASESPEC.fields_by_name['product_slug']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['namespace']._options = None
  _K8SRELEASESPEC.fields_by_name['namespace']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['application_name']._options = None
  _K8SRELEASESPEC.fields_by_name['application_name']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _K8SRELEASESPEC.fields_by_name['values']._options = None
  _K8SRELEASESPEC.fields_by_name['values']._serialized_options = b'\272J\001\004\300J\001'
  _K8SRELEASESPEC.fields_by_name['set']._options = None
  _K8SRELEASESPEC.fields_by_name['set']._serialized_options = b'\272J\001\004\300J\001'
  _globals['_K8SRELEASE']._serialized_start=169
  _globals['_K8SRELEASE']._serialized_end=411
  _globals['_K8SRELEASESPEC']._serialized_start=414
  _globals['_K8SRELEASESPEC']._serialized_end=788
  _globals['_K8SRELEASESPEC_SETENTRY']._serialized_start=734
  _globals['_K8SRELEASESPEC_SETENTRY']._serialized_end=788
  _globals['_K8SRELEASESTATUS']._serialized_start=791
  _globals['_K8SRELEASESTATUS']._serialized_end=1016
  _globals['_K8SRELEASESTATUS_STATE']._serialized_start=924
  _globals['_K8SRELEASESTATUS_STATE']._serialized_end=1016
# @@protoc_insertion_point(module_scope)
