# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/federation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/iam/v1/federation.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xd4\x01\n\nFederation\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.FederationSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12=\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.iam.v1.FederationStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xc2\x01\n\x0e\x46\x65\x64\x65rationSpec\x12;\n\x1auser_account_auto_creation\x18\x01 \x01(\x08R\x17userAccountAutoCreation\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x42\n\rsaml_settings\x18\n \x01(\x0b\x32\x1b.nebius.iam.v1.SamlSettingsH\x00R\x0csamlSettingsB\x11\n\x08settings\x12\x05\xbaH\x02\x08\x01J\x04\x08\x03\x10\x04\"g\n\x0cSamlSettings\x12\x1d\n\nidp_issuer\x18\x01 \x01(\tR\tidpIssuer\x12\x17\n\x07sso_url\x18\x02 \x01(\tR\x06ssoUrl\x12\x1f\n\x0b\x66orce_authn\x18\x03 \x01(\x08R\nforceAuthn\"\x12\n\x10\x46\x65\x64\x65rationStatusBV\n\x14\x61i.nebius.pub.iam.v1B\x0f\x46\x65\x64\x65rationProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.federation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\017FederationProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _FEDERATION.fields_by_name['metadata']._options = None
  _FEDERATION.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATION.fields_by_name['spec']._options = None
  _FEDERATION.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATION.fields_by_name['status']._options = None
  _FEDERATION.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _FEDERATION._options = None
  _FEDERATION._serialized_options = b'\272J\001\002'
  _FEDERATIONSPEC.oneofs_by_name['settings']._options = None
  _FEDERATIONSPEC.oneofs_by_name['settings']._serialized_options = b'\272H\002\010\001'
  _globals['_FEDERATION']._serialized_start=138
  _globals['_FEDERATION']._serialized_end=350
  _globals['_FEDERATIONSPEC']._serialized_start=353
  _globals['_FEDERATIONSPEC']._serialized_end=547
  _globals['_SAMLSETTINGS']._serialized_start=549
  _globals['_SAMLSETTINGS']._serialized_end=652
  _globals['_FEDERATIONSTATUS']._serialized_start=654
  _globals['_FEDERATIONSTATUS']._serialized_end=672
# @@protoc_insertion_point(module_scope)
