# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/session_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nebius/iam/v1/session_management_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\"\xad\x01\n\x14RevokeSessionRequest\x12.\n\x12service_account_id\x18\x03 \x01(\tH\x00R\x10serviceAccountId\x12$\n\rall_my_active\x18\x06 \x01(\x08H\x00R\x0b\x61llMyActive\x12\x35\n\x16tenant_user_account_id\x18\x07 \x01(\tH\x00R\x13tenantUserAccountIdB\x08\n\x06revoke\"\x17\n\x15RevokeSessionResponse2{\n\x18SessionManagementService\x12S\n\x06Revoke\x12#.nebius.iam.v1.RevokeSessionRequest\x1a$.nebius.iam.v1.RevokeSessionResponse\x1a\n\xbaJ\x07\x63pl.iamBd\n\x14\x61i.nebius.pub.iam.v1B\x1dSessionManagementServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.session_management_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\035SessionManagementServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _SESSIONMANAGEMENTSERVICE._options = None
  _SESSIONMANAGEMENTSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_REVOKESESSIONREQUEST']._serialized_start=92
  _globals['_REVOKESESSIONREQUEST']._serialized_end=265
  _globals['_REVOKESESSIONRESPONSE']._serialized_start=267
  _globals['_REVOKESESSIONRESPONSE']._serialized_end=290
  _globals['_SESSIONMANAGEMENTSERVICE']._serialized_start=292
  _globals['_SESSIONMANAGEMENTSERVICE']._serialized_end=415
# @@protoc_insertion_point(module_scope)
