# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/secret_version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.mysterybox.v1 import payload_pb2 as nebius_dot_mysterybox_dot_v1_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/mysterybox/v1/secret_version.proto\x12\x14nebius.mysterybox.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a\"nebius/mysterybox/v1/payload.proto\"\xdb\x01\n\rSecretVersion\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.mysterybox.v1.SecretVersionSpecR\x04spec\x12G\n\x06status\x18\x03 \x01(\x0b\x32).nebius.mysterybox.v1.SecretVersionStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xa8\x01\n\x11SecretVersionSpec\x12&\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x0b\x64\x65scription\x12\x44\n\x07payload\x18\x02 \x03(\x0b\x32\x1d.nebius.mysterybox.v1.PayloadB\x0b\xbaH\x03\xc8\x01\x01\xbaJ\x02\x04\x02R\x07payload\x12%\n\x0bset_primary\x18\x03 \x01(\x08\x42\x04\xbaJ\x01\x04R\nsetPrimary\"\x96\x02\n\x13SecretVersionStatus\x12\x45\n\x05state\x18\x01 \x01(\x0e\x32/.nebius.mysterybox.v1.SecretVersionStatus.StateR\x05state\x12\x39\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\x12\x35\n\x08purge_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07purgeAt\"F\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1a\n\x16SCHEDULED_FOR_DELETION\x10\x02\x42g\n\x1b\x61i.nebius.pub.mysterybox.v1B\x12SecretVersionProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.secret_version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\022SecretVersionProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _SECRETVERSION.fields_by_name['status']._options = None
  _SECRETVERSION.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _SECRETVERSION._options = None
  _SECRETVERSION._serialized_options = b'\272J\001\002'
  _SECRETVERSIONSPEC.fields_by_name['description']._options = None
  _SECRETVERSIONSPEC.fields_by_name['description']._serialized_options = b'\272J\001\002'
  _SECRETVERSIONSPEC.fields_by_name['payload']._options = None
  _SECRETVERSIONSPEC.fields_by_name['payload']._serialized_options = b'\272H\003\310\001\001\272J\002\004\002'
  _SECRETVERSIONSPEC.fields_by_name['set_primary']._options = None
  _SECRETVERSIONSPEC.fields_by_name['set_primary']._serialized_options = b'\272J\001\004'
  _globals['_SECRETVERSION']._serialized_start=225
  _globals['_SECRETVERSION']._serialized_end=444
  _globals['_SECRETVERSIONSPEC']._serialized_start=447
  _globals['_SECRETVERSIONSPEC']._serialized_end=615
  _globals['_SECRETVERSIONSTATUS']._serialized_start=618
  _globals['_SECRETVERSIONSTATUS']._serialized_end=896
  _globals['_SECRETVERSIONSTATUS_STATE']._serialized_start=826
  _globals['_SECRETVERSIONSTATUS_STATE']._serialized_end=896
# @@protoc_insertion_point(module_scope)
