# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/access_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/iam/v1/access_key.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a\x1anebius/iam/v1/access.proto\"\xd1\x01\n\tAccessKey\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x38\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.AccessKeySpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12<\n\x06status\x18\x03 \x01(\x0b\x32\x1e.nebius.iam.v1.AccessKeyStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"\xaa\x01\n\rAccessKeySpec\x12\x36\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountB\x04\xbaJ\x01\x02R\x07\x61\x63\x63ount\x12?\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xbaJ\x01\x02R\texpiresAt\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"\xd2\x02\n\x0f\x41\x63\x63\x65ssKeyStatus\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.nebius.iam.v1.AccessKeyStatus.StateR\x05state\x12 \n\x0b\x66ingerprint\x18\x02 \x01(\tR\x0b\x66ingerprint\x12\x1c\n\talgorithm\x18\x03 \x01(\tR\talgorithm\x12\x19\n\x08key_size\x18\x04 \x01(\x05R\x07keySize\x12)\n\x11\x61ws_access_key_id\x18\x05 \x01(\tR\x0e\x61wsAccessKeyId\x12\x1b\n\x06secret\x18\x06 \x01(\tB\x03\xc0J\x01R\x06secret\"`\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\x0b\n\x07\x45XPIRED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\x0b\n\x07\x44\x45LETED\x10\x05\x42U\n\x14\x61i.nebius.pub.iam.v1B\x0e\x41\x63\x63\x65ssKeyProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.access_key_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\016AccessKeyProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _ACCESSKEY.fields_by_name['metadata']._options = None
  _ACCESSKEY.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _ACCESSKEY.fields_by_name['spec']._options = None
  _ACCESSKEY.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ACCESSKEY.fields_by_name['status']._options = None
  _ACCESSKEY.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _ACCESSKEY._options = None
  _ACCESSKEY._serialized_options = b'\272J\001\002'
  _ACCESSKEYSPEC.fields_by_name['account']._options = None
  _ACCESSKEYSPEC.fields_by_name['account']._serialized_options = b'\272J\001\002'
  _ACCESSKEYSPEC.fields_by_name['expires_at']._options = None
  _ACCESSKEYSPEC.fields_by_name['expires_at']._serialized_options = b'\272J\001\002'
  _ACCESSKEYSTATUS.fields_by_name['secret']._options = None
  _ACCESSKEYSTATUS.fields_by_name['secret']._serialized_options = b'\300J\001'
  _globals['_ACCESSKEY']._serialized_start=199
  _globals['_ACCESSKEY']._serialized_end=408
  _globals['_ACCESSKEYSPEC']._serialized_start=411
  _globals['_ACCESSKEYSPEC']._serialized_end=581
  _globals['_ACCESSKEYSTATUS']._serialized_start=584
  _globals['_ACCESSKEYSTATUS']._serialized_end=922
  _globals['_ACCESSKEYSTATUS_STATE']._serialized_start=826
  _globals['_ACCESSKEYSTATUS_STATE']._serialized_end=922
# @@protoc_insertion_point(module_scope)
