# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v2/project_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v2 import project_pb2 as nebius_dot_iam_dot_v2_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#nebius/iam/v2/project_service.proto\x12\rnebius.iam.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1bnebius/iam/v2/project.proto\"\x86\x01\n\x14\x43reateProjectRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12.\n\x04spec\x18\x02 \x01(\x0b\x32\x1a.nebius.iam.v2.ProjectSpecR\x04spec\"#\n\x11GetProjectRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x17GetProjectByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x86\x01\n\x13ListProjectsRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x86\x01\n\x14UpdateProjectRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12.\n\x04spec\x18\x02 \x01(\x0b\x32\x1a.nebius.iam.v2.ProjectSpecR\x04spec\"&\n\x14\x44\x65leteProjectRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"l\n\x14ListProjectsResponse\x12,\n\x05items\x18\x01 \x03(\x0b\x32\x16.nebius.iam.v2.ProjectR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xdf\x03\n\x0eProjectService\x12J\n\x06\x43reate\x12#.nebius.iam.v2.CreateProjectRequest\x1a\x1b.nebius.common.v1.Operation\x12?\n\x03Get\x12 .nebius.iam.v2.GetProjectRequest\x1a\x16.nebius.iam.v2.Project\x12K\n\tGetByName\x12&.nebius.iam.v2.GetProjectByNameRequest\x1a\x16.nebius.iam.v2.Project\x12O\n\x04List\x12\".nebius.iam.v2.ListProjectsRequest\x1a#.nebius.iam.v2.ListProjectsResponse\x12J\n\x06Update\x12#.nebius.iam.v2.UpdateProjectRequest\x1a\x1b.nebius.common.v1.Operation\x12J\n\x06\x44\x65lete\x12#.nebius.iam.v2.DeleteProjectRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamBZ\n\x14\x61i.nebius.pub.iam.v2B\x13ProjectServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v2.project_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v2B\023ProjectServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v2'
  _GETPROJECTBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETPROJECTBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETPROJECTBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETPROJECTBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _PROJECTSERVICE._options = None
  _PROJECTSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEPROJECTREQUEST']._serialized_start=206
  _globals['_CREATEPROJECTREQUEST']._serialized_end=340
  _globals['_GETPROJECTREQUEST']._serialized_start=342
  _globals['_GETPROJECTREQUEST']._serialized_end=377
  _globals['_GETPROJECTBYNAMEREQUEST']._serialized_start=379
  _globals['_GETPROJECTBYNAMEREQUEST']._serialized_end=469
  _globals['_LISTPROJECTSREQUEST']._serialized_start=472
  _globals['_LISTPROJECTSREQUEST']._serialized_end=606
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=609
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=743
  _globals['_DELETEPROJECTREQUEST']._serialized_start=745
  _globals['_DELETEPROJECTREQUEST']._serialized_end=783
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=785
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=893
  _globals['_PROJECTSERVICE']._serialized_start=896
  _globals['_PROJECTSERVICE']._serialized_end=1375
# @@protoc_insertion_point(module_scope)
