# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/platform_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.compute.v1 import platform_pb2 as nebius_dot_compute_dot_v1_dot_platform__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/compute/v1/platform_service.proto\x12\x11nebius.compute.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/compute/v1/platform.proto\"w\n\x14ListPlatformsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12#\n\tparent_id\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\"r\n\x15ListPlatformsResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.compute.v1.PlatformR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xc6\x01\n\x0fPlatformService\x12L\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x1b.nebius.compute.v1.Platform\x12Y\n\x04List\x12\'.nebius.compute.v1.ListPlatformsRequest\x1a(.nebius.compute.v1.ListPlatformsResponse\x1a\n\xbaJ\x07\x63omputeBc\n\x18\x61i.nebius.pub.compute.v1B\x14PlatformServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.platform_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\024PlatformServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _LISTPLATFORMSREQUEST.fields_by_name['parent_id']._options = None
  _LISTPLATFORMSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _PLATFORMSERVICE._options = None
  _PLATFORMSERVICE._serialized_options = b'\272J\007compute'
  _globals['_LISTPLATFORMSREQUEST']._serialized_start=185
  _globals['_LISTPLATFORMSREQUEST']._serialized_end=304
  _globals['_LISTPLATFORMSRESPONSE']._serialized_start=306
  _globals['_LISTPLATFORMSRESPONSE']._serialized_end=420
  _globals['_PLATFORMSERVICE']._serialized_start=423
  _globals['_PLATFORMSERVICE']._serialized_end=621
# @@protoc_insertion_point(module_scope)
