# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/invitation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/iam/v1/invitation.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xd4\x01\n\nInvitation\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.InvitationSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12=\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.iam.v1.InvitationStatusB\x04\xbaJ\x01\x05R\x06status:\x04\xbaJ\x01\x02\"Z\n\x0eInvitationSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\x05\x65mail\x18\x0b \x01(\tB\x03\xc0J\x01H\x00R\x05\x65mailB\t\n\x07\x63ontact\"\x9c\x02\n\x10InvitationStatus\x12\x33\n\x16tenant_user_account_id\x18\x01 \x01(\tR\x13tenantUserAccountId\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12;\n\x05state\x18\x03 \x01(\x0e\x32%.nebius.iam.v1.InvitationStatus.StateR\x05state\"[\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x04\x12\x0b\n\x07\x43REATED\x10\x05\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x03\x42V\n\x14\x61i.nebius.pub.iam.v1B\x0fInvitationProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.invitation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\017InvitationProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _INVITATION.fields_by_name['metadata']._options = None
  _INVITATION.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _INVITATION.fields_by_name['spec']._options = None
  _INVITATION.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _INVITATION.fields_by_name['status']._options = None
  _INVITATION.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _INVITATION._options = None
  _INVITATION._serialized_options = b'\272J\001\002'
  _INVITATIONSPEC.fields_by_name['email']._options = None
  _INVITATIONSPEC.fields_by_name['email']._serialized_options = b'\300J\001'
  _globals['_INVITATION']._serialized_start=171
  _globals['_INVITATION']._serialized_end=383
  _globals['_INVITATIONSPEC']._serialized_start=385
  _globals['_INVITATIONSPEC']._serialized_end=475
  _globals['_INVITATIONSTATUS']._serialized_start=478
  _globals['_INVITATIONSTATUS']._serialized_end=762
  _globals['_INVITATIONSTATUS_STATE']._serialized_start=671
  _globals['_INVITATIONSTATUS_STATE']._serialized_end=762
# @@protoc_insertion_point(module_scope)
