# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnebius/audit/v2/request.proto\x12\x0fnebius.audit.v2\x1a\x1cgoogle/protobuf/struct.proto\"\x88\x02\n\x07Request\x12\x1b\n\tclient_ip\x18\x01 \x01(\tR\x08\x63lientIp\x12\x1d\n\nuser_agent\x18\x02 \x01(\tR\tuserAgent\x12\x1d\n\nrequest_id\x18\x03 \x01(\tR\trequestId\x12\x37\n\nparameters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12%\n\x0eidempotency_id\x18\x05 \x01(\tR\ridempotencyId\x12\x19\n\x08trace_id\x18\x06 \x01(\tR\x07traceId\x12\'\n\x0fja3_fingerprint\x18\x07 \x01(\tR\x0eja3FingerprintBW\n\x16\x61i.nebius.pub.audit.v2B\x0cRequestProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\014RequestProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_REQUEST']._serialized_start=81
  _globals['_REQUEST']._serialized_end=345
# @@protoc_insertion_point(module_scope)
