# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/payload_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.mysterybox.v1 import payload_pb2 as nebius_dot_mysterybox_dot_v1_dot_payload__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/mysterybox/v1/payload_service.proto\x12\x14nebius.mysterybox.v1\x1a\"nebius/mysterybox/v1/payload.proto\x1a\x18nebius/annotations.proto\x1a\x1b\x62uf/validate/validate.proto\"U\n\x11GetPayloadRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\x12#\n\nversion_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\tversionId\"t\n\x16GetPayloadByKeyRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\x12#\n\nversion_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\tversionId\x12\x18\n\x03key\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03key\"a\n\rSecretPayload\x12\x1d\n\nversion_id\x18\x01 \x01(\tR\tversionId\x12\x31\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1d.nebius.mysterybox.v1.PayloadR\x04\x64\x61ta\"f\n\x12SecretPayloadEntry\x12\x1d\n\nversion_id\x18\x01 \x01(\tR\tversionId\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.nebius.mysterybox.v1.PayloadR\x04\x64\x61ta2\xdc\x01\n\x0ePayloadService\x12S\n\x03Get\x12\'.nebius.mysterybox.v1.GetPayloadRequest\x1a#.nebius.mysterybox.v1.SecretPayload\x12\x62\n\x08GetByKey\x12,.nebius.mysterybox.v1.GetPayloadByKeyRequest\x1a(.nebius.mysterybox.v1.SecretPayloadEntry\x1a\x11\xbaJ\x0e\x64pl.mysteryboxBh\n\x1b\x61i.nebius.pub.mysterybox.v1B\x13PayloadServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.payload_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\023PayloadServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _GETPAYLOADREQUEST.fields_by_name['version_id']._options = None
  _GETPAYLOADREQUEST.fields_by_name['version_id']._serialized_options = b'\272J\001\007'
  _GETPAYLOADBYKEYREQUEST.fields_by_name['version_id']._options = None
  _GETPAYLOADBYKEYREQUEST.fields_by_name['version_id']._serialized_options = b'\272J\001\007'
  _GETPAYLOADBYKEYREQUEST.fields_by_name['key']._options = None
  _GETPAYLOADBYKEYREQUEST.fields_by_name['key']._serialized_options = b'\272H\003\310\001\001'
  _PAYLOADSERVICE._options = None
  _PAYLOADSERVICE._serialized_options = b'\272J\016dpl.mysterybox'
  _globals['_GETPAYLOADREQUEST']._serialized_start=159
  _globals['_GETPAYLOADREQUEST']._serialized_end=244
  _globals['_GETPAYLOADBYKEYREQUEST']._serialized_start=246
  _globals['_GETPAYLOADBYKEYREQUEST']._serialized_end=362
  _globals['_SECRETPAYLOAD']._serialized_start=364
  _globals['_SECRETPAYLOAD']._serialized_end=461
  _globals['_SECRETPAYLOADENTRY']._serialized_start=463
  _globals['_SECRETPAYLOADENTRY']._serialized_end=565
  _globals['_PAYLOADSERVICE']._serialized_start=568
  _globals['_PAYLOADSERVICE']._serialized_end=788
# @@protoc_insertion_point(module_scope)
