# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.vpc.v1alpha1 import network_interface_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_network__interface__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/compute/v1alpha1/instance.proto\x12\x17nebius.compute.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a+nebius/vpc/v1alpha1/network_interface.proto\"\xc6\x01\n\x08Instance\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.InstanceSpecR\x04spec\x12?\n\x06status\x18\x03 \x01(\x0b\x32\'.nebius.compute.v1alpha1.InstanceStatusR\x06status\"\x83\x06\n\x0cInstanceSpec\x12\x32\n\x12service_account_id\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x10serviceAccountId\x12P\n\tresources\x18\x02 \x01(\x0b\x32&.nebius.compute.v1alpha1.ResourcesSpecB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tresources\x12V\n\x0bgpu_cluster\x18\x03 \x01(\x0b\x32/.nebius.compute.v1alpha1.InstanceGpuClusterSpecB\x04\xbaJ\x01\x02R\ngpuCluster\x12\x64\n\x12network_interfaces\x18\x04 \x03(\x0b\x32).nebius.vpc.v1alpha1.NetworkInterfaceSpecB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x11networkInterfaces\x12L\n\tboot_disk\x18\x05 \x01(\x0b\x32).nebius.compute.v1alpha1.AttachedDiskSpecB\x04\xbaJ\x01\x02R\x08\x62ootDisk\x12R\n\x0fsecondary_disks\x18\x06 \x03(\x0b\x32).nebius.compute.v1alpha1.AttachedDiskSpecR\x0esecondaryDisks\x12W\n\x0b\x66ilesystems\x18\x07 \x03(\x0b\x32/.nebius.compute.v1alpha1.AttachedFilesystemSpecB\x04\xbaJ\x01\x02R\x0b\x66ilesystems\x12\x34\n\x14\x63loud_init_user_data\x18\x08 \x01(\tB\x03\xc0J\x01R\x11\x63loudInitUserData\x12\x18\n\x07stopped\x18\r \x01(\x08R\x07stopped\x12^\n\x0frecovery_policy\x18\x0f \x01(\x0e\x32/.nebius.compute.v1alpha1.InstanceRecoveryPolicyB\x04\xbaJ\x01\x02R\x0erecoveryPolicyJ\x04\x08\x0b\x10\x0c\"\\\n\rResourcesSpec\x12\"\n\x08platform\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x18\n\x06preset\x18\x02 \x01(\tH\x00R\x06presetB\r\n\x04size\x12\x05\xbaH\x02\x08\x01\"(\n\x16InstanceGpuClusterSpec\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb6\x02\n\x10\x41ttachedDiskSpec\x12]\n\x0b\x61ttach_mode\x18\x01 \x01(\x0e\x32\x34.nebius.compute.v1alpha1.AttachedDiskSpec.AttachModeB\x06\xbaH\x03\xc8\x01\x01R\nattachMode\x12L\n\rexisting_disk\x18\x02 \x01(\x0b\x32%.nebius.compute.v1alpha1.ExistingDiskH\x00R\x0c\x65xistingDisk\x12(\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\ndeviceName\"<\n\nAttachMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\r\n\x04type\x12\x05\xbaH\x02\x08\x01\"&\n\x0c\x45xistingDisk\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\",\n\x12\x45xistingFilesystem\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xd3\x02\n\x16\x41ttachedFilesystemSpec\x12\x63\n\x0b\x61ttach_mode\x18\x01 \x01(\x0e\x32:.nebius.compute.v1alpha1.AttachedFilesystemSpec.AttachModeB\x06\xbaH\x03\xc8\x01\x01R\nattachMode\x12\'\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\ndeviceName\x12^\n\x13\x65xisting_filesystem\x18\x03 \x01(\x0b\x32+.nebius.compute.v1alpha1.ExistingFilesystemH\x00R\x12\x65xistingFilesystem\"<\n\nAttachMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\r\n\x04type\x12\x05\xbaH\x02\x08\x01\"\xe9\x02\n\x0eInstanceStatus\x12K\n\x05state\x18\x01 \x01(\x0e\x32\x35.nebius.compute.v1alpha1.InstanceStatus.InstanceStateR\x05state\x12Z\n\x12network_interfaces\x18\x02 \x03(\x0b\x32+.nebius.vpc.v1alpha1.NetworkInterfaceStatusR\x11networkInterfaces\x12 \n\x0breconciling\x18\x05 \x01(\x08R\x0breconciling\"\x8b\x01\n\rInstanceState\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08UPDATING\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\t\n\x05\x45RROR\x10\x08*/\n\x16InstanceRecoveryPolicy\x12\x0b\n\x07RECOVER\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x42k\n\x1e\x61i.nebius.pub.compute.v1alpha1B\rInstanceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\rInstanceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _INSTANCESPEC.fields_by_name['service_account_id']._options = None
  _INSTANCESPEC.fields_by_name['service_account_id']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['resources']._options = None
  _INSTANCESPEC.fields_by_name['resources']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _INSTANCESPEC.fields_by_name['gpu_cluster']._options = None
  _INSTANCESPEC.fields_by_name['gpu_cluster']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['network_interfaces']._options = None
  _INSTANCESPEC.fields_by_name['network_interfaces']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _INSTANCESPEC.fields_by_name['boot_disk']._options = None
  _INSTANCESPEC.fields_by_name['boot_disk']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['filesystems']._options = None
  _INSTANCESPEC.fields_by_name['filesystems']._serialized_options = b'\272J\001\002'
  _INSTANCESPEC.fields_by_name['cloud_init_user_data']._options = None
  _INSTANCESPEC.fields_by_name['cloud_init_user_data']._serialized_options = b'\300J\001'
  _INSTANCESPEC.fields_by_name['recovery_policy']._options = None
  _INSTANCESPEC.fields_by_name['recovery_policy']._serialized_options = b'\272J\001\002'
  _RESOURCESSPEC.oneofs_by_name['size']._options = None
  _RESOURCESSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _RESOURCESSPEC.fields_by_name['platform']._options = None
  _RESOURCESSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDDISKSPEC.oneofs_by_name['type']._options = None
  _ATTACHEDDISKSPEC.oneofs_by_name['type']._serialized_options = b'\272H\002\010\001'
  _ATTACHEDDISKSPEC.fields_by_name['attach_mode']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['attach_mode']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDDISKSPEC.fields_by_name['device_name']._serialized_options = b'\272H\004r\002\030\024'
  _EXISTINGDISK.fields_by_name['id']._options = None
  _EXISTINGDISK.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _EXISTINGFILESYSTEM.fields_by_name['id']._options = None
  _EXISTINGFILESYSTEM.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDFILESYSTEMSPEC.oneofs_by_name['type']._options = None
  _ATTACHEDFILESYSTEMSPEC.oneofs_by_name['type']._serialized_options = b'\272H\002\010\001'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['attach_mode']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['attach_mode']._serialized_options = b'\272H\003\310\001\001'
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._options = None
  _ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_INSTANCERECOVERYPOLICY']._serialized_start=2416
  _globals['_INSTANCERECOVERYPOLICY']._serialized_end=2463
  _globals['_INSTANCE']._serialized_start=201
  _globals['_INSTANCE']._serialized_end=399
  _globals['_INSTANCESPEC']._serialized_start=402
  _globals['_INSTANCESPEC']._serialized_end=1173
  _globals['_RESOURCESSPEC']._serialized_start=1175
  _globals['_RESOURCESSPEC']._serialized_end=1267
  _globals['_INSTANCEGPUCLUSTERSPEC']._serialized_start=1269
  _globals['_INSTANCEGPUCLUSTERSPEC']._serialized_end=1309
  _globals['_ATTACHEDDISKSPEC']._serialized_start=1312
  _globals['_ATTACHEDDISKSPEC']._serialized_end=1622
  _globals['_ATTACHEDDISKSPEC_ATTACHMODE']._serialized_start=1547
  _globals['_ATTACHEDDISKSPEC_ATTACHMODE']._serialized_end=1607
  _globals['_EXISTINGDISK']._serialized_start=1624
  _globals['_EXISTINGDISK']._serialized_end=1662
  _globals['_EXISTINGFILESYSTEM']._serialized_start=1664
  _globals['_EXISTINGFILESYSTEM']._serialized_end=1708
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_start=1711
  _globals['_ATTACHEDFILESYSTEMSPEC']._serialized_end=2050
  _globals['_ATTACHEDFILESYSTEMSPEC_ATTACHMODE']._serialized_start=1547
  _globals['_ATTACHEDFILESYSTEMSPEC_ATTACHMODE']._serialized_end=1607
  _globals['_INSTANCESTATUS']._serialized_start=2053
  _globals['_INSTANCESTATUS']._serialized_end=2414
  _globals['_INSTANCESTATUS_INSTANCESTATE']._serialized_start=2275
  _globals['_INSTANCESTATUS_INSTANCESTATE']._serialized_end=2414
# @@protoc_insertion_point(module_scope)
