# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/applications/v1alpha1/k8s_release_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.applications.v1alpha1 import k8s_release_pb2 as nebius_dot_applications_dot_v1alpha1_dot_k8s__release__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6nebius/applications/v1alpha1/k8s_release_service.proto\x12\x1cnebius.applications.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a.nebius/applications/v1alpha1/k8s_release.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\".\n\x14GetK8sReleaseRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xb8\x01\n\x16ListK8sReleasesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\x12%\n\ncluster_id\x18\x05 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tclusterId\"\x9b\x01\n\x17\x43reateK8sReleaseRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecR\x04spec\"\x9b\x01\n\x17UpdateK8sReleaseRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.applications.v1alpha1.K8sReleaseSpecR\x04spec\"1\n\x17\x44\x65leteK8sReleaseRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x81\x01\n\x17ListK8sReleasesResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.applications.v1alpha1.K8sReleaseR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xa2\x04\n\x11K8sReleaseService\x12\x63\n\x03Get\x12\x32.nebius.applications.v1alpha1.GetK8sReleaseRequest\x1a(.nebius.applications.v1alpha1.K8sRelease\x12s\n\x04List\x12\x34.nebius.applications.v1alpha1.ListK8sReleasesRequest\x1a\x35.nebius.applications.v1alpha1.ListK8sReleasesResponse\x12\\\n\x06\x43reate\x12\x35.nebius.applications.v1alpha1.CreateK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x12\\\n\x06Update\x12\x35.nebius.applications.v1alpha1.UpdateK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x12\\\n\x06\x44\x65lete\x12\x35.nebius.applications.v1alpha1.DeleteK8sReleaseRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x19\xbaJ\x16\x64\x65ployment-manager.mktB{\n#ai.nebius.pub.applications.v1alpha1B\x16K8SReleaseServiceProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.applications.v1alpha1.k8s_release_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.applications.v1alpha1B\026K8SReleaseServiceProtoP\001Z:github.com/nebius/gosdk/proto/nebius/applications/v1alpha1'
  _GETK8SRELEASEREQUEST.fields_by_name['id']._options = None
  _GETK8SRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTK8SRELEASESREQUEST.fields_by_name['parent_id']._options = None
  _LISTK8SRELEASESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTK8SRELEASESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTK8SRELEASESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEK8SRELEASEREQUEST.fields_by_name['id']._options = None
  _DELETEK8SRELEASEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _K8SRELEASESERVICE._options = None
  _K8SRELEASESERVICE._serialized_options = b'\272J\026deployment-manager.mkt'
  _globals['_GETK8SRELEASEREQUEST']._serialized_start=258
  _globals['_GETK8SRELEASEREQUEST']._serialized_end=304
  _globals['_LISTK8SRELEASESREQUEST']._serialized_start=307
  _globals['_LISTK8SRELEASESREQUEST']._serialized_end=491
  _globals['_CREATEK8SRELEASEREQUEST']._serialized_start=494
  _globals['_CREATEK8SRELEASEREQUEST']._serialized_end=649
  _globals['_UPDATEK8SRELEASEREQUEST']._serialized_start=652
  _globals['_UPDATEK8SRELEASEREQUEST']._serialized_end=807
  _globals['_DELETEK8SRELEASEREQUEST']._serialized_start=809
  _globals['_DELETEK8SRELEASEREQUEST']._serialized_end=858
  _globals['_LISTK8SRELEASESRESPONSE']._serialized_start=861
  _globals['_LISTK8SRELEASESRESPONSE']._serialized_end=990
  _globals['_K8SRELEASESERVICE']._serialized_start=993
  _globals['_K8SRELEASESERVICE']._serialized_end=1539
# @@protoc_insertion_point(module_scope)
