# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius.audit.v2 import authentication_pb2 as nebius_dot_audit_dot_v2_dot_authentication__pb2
from nebius.api.nebius.audit.v2 import authorization_pb2 as nebius_dot_audit_dot_v2_dot_authorization__pb2
from nebius.api.nebius.audit.v2 import region_pb2 as nebius_dot_audit_dot_v2_dot_region__pb2
from nebius.api.nebius.audit.v2 import request_pb2 as nebius_dot_audit_dot_v2_dot_request__pb2
from nebius.api.nebius.audit.v2 import resource_pb2 as nebius_dot_audit_dot_v2_dot_resource__pb2
from nebius.api.nebius.audit.v2 import response_pb2 as nebius_dot_audit_dot_v2_dot_response__pb2
from nebius.api.nebius.audit.v2 import service_pb2 as nebius_dot_audit_dot_v2_dot_service__pb2
from nebius.api.nebius.audit.v2 import status_pb2 as nebius_dot_audit_dot_v2_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/audit/v2/audit_event.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$nebius/audit/v2/authentication.proto\x1a#nebius/audit/v2/authorization.proto\x1a\x1cnebius/audit/v2/region.proto\x1a\x1dnebius/audit/v2/request.proto\x1a\x1enebius/audit/v2/resource.proto\x1a\x1enebius/audit/v2/response.proto\x1a\x1dnebius/audit/v2/service.proto\x1a\x1cnebius/audit/v2/status.proto\"\xf6\x05\n\nAuditEvent\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x1e\n\x06source\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06source\x12)\n\x0cspec_version\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0bspecVersion\x12\x1a\n\x04type\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04type\x12:\n\x07service\x18\x05 \x01(\x0b\x32\x18.nebius.audit.v2.ServiceB\x06\xbaH\x03\xc8\x01\x01R\x07service\x12\x1e\n\x06\x61\x63tion\x18\x06 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06\x61\x63tion\x12\x36\n\x04time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x04time\x12+\n\revent_version\x18\x08 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0c\x65ventVersion\x12G\n\x0e\x61uthentication\x18\t \x01(\x0b\x32\x1f.nebius.audit.v2.AuthenticationR\x0e\x61uthentication\x12\x44\n\rauthorization\x18\n \x01(\x0b\x32\x1e.nebius.audit.v2.AuthorizationR\rauthorization\x12\x35\n\x08resource\x18\x0b \x01(\x0b\x32\x19.nebius.audit.v2.ResourceR\x08resource\x12\x32\n\x07request\x18\x0c \x01(\x0b\x32\x18.nebius.audit.v2.RequestR\x07request\x12\x35\n\x08response\x18\r \x01(\x0b\x32\x19.nebius.audit.v2.ResponseR\x08response\x12\x37\n\x06status\x18\x10 \x01(\x0e\x32\x17.nebius.audit.v2.StatusB\x06\xbaH\x03\xc8\x01\x01R\x06status\x12>\n\x0eproject_region\x18\x11 \x01(\x0b\x32\x17.nebius.audit.v2.RegionR\rprojectRegionBZ\n\x16\x61i.nebius.pub.audit.v2B\x0f\x41uditEventProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\017AuditEventProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUDITEVENT.fields_by_name['id']._options = None
  _AUDITEVENT.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['source']._options = None
  _AUDITEVENT.fields_by_name['source']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['spec_version']._options = None
  _AUDITEVENT.fields_by_name['spec_version']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['type']._options = None
  _AUDITEVENT.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['service']._options = None
  _AUDITEVENT.fields_by_name['service']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['action']._options = None
  _AUDITEVENT.fields_by_name['action']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['time']._options = None
  _AUDITEVENT.fields_by_name['time']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['event_version']._options = None
  _AUDITEVENT.fields_by_name['event_version']._serialized_options = b'\272H\003\310\001\001'
  _AUDITEVENT.fields_by_name['status']._options = None
  _AUDITEVENT.fields_by_name['status']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUDITEVENT']._serialized_start=378
  _globals['_AUDITEVENT']._serialized_end=1136
# @@protoc_insertion_point(module_scope)
