# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/scope.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnebius/vpc/v1alpha1/scope.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xb5\x01\n\x05Scope\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1alpha1.ScopeSpecR\x04spec\x12\x38\n\x06status\x18\x03 \x01(\x0b\x32 .nebius.vpc.v1alpha1.ScopeStatusR\x06status\"\x89\x01\n\tScopeSpec\x12?\n\x04type\x18\x01 \x01(\x0e\x32#.nebius.vpc.v1alpha1.ScopeSpec.TypeB\x06\xbaH\x03\xc8\x01\x01R\x04type\";\n\x04Type\x12\x1a\n\x16SCOPE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\x92\x01\n\x0bScopeStatus\x12<\n\x05state\x18\x01 \x01(\x0e\x32&.nebius.vpc.v1alpha1.ScopeStatus.StateR\x05state\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42]\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\nScopeProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.scope_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\nScopeProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _SCOPESPEC.fields_by_name['type']._options = None
  _SCOPESPEC.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SCOPE']._serialized_start=119
  _globals['_SCOPE']._serialized_end=300
  _globals['_SCOPESPEC']._serialized_start=303
  _globals['_SCOPESPEC']._serialized_end=440
  _globals['_SCOPESPEC_TYPE']._serialized_start=381
  _globals['_SCOPESPEC_TYPE']._serialized_end=440
  _globals['_SCOPESTATUS']._serialized_start=443
  _globals['_SCOPESTATUS']._serialized_end=589
  _globals['_SCOPESTATUS_STATE']._serialized_start=520
  _globals['_SCOPESTATUS_STATE']._serialized_end=589
# @@protoc_insertion_point(module_scope)
