# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/subject.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnebius/audit/v2/subject.proto\x12\x0fnebius.audit.v2\"{\n\x07Subject\x12.\n\x12service_account_id\x18\n \x01(\tH\x00R\x10serviceAccountId\x12&\n\x0etenant_user_id\x18\x0b \x01(\tH\x00R\x0ctenantUserId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04nameB\x04\n\x02idBW\n\x16\x61i.nebius.pub.audit.v2B\x0cSubjectProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.subject_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\014SubjectProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_SUBJECT']._serialized_start=50
  _globals['_SUBJECT']._serialized_end=173
# @@protoc_insertion_point(module_scope)
