# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1.config import postgresql_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_config_dot_postgresql__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import template_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_template__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/msp/postgresql/v1alpha1/cluster.proto\x12\x1enebius.msp.postgresql.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a!nebius/msp/v1alpha1/cluster.proto\x1a\x36nebius/msp/postgresql/v1alpha1/config/postgresql.proto\x1a-nebius/msp/postgresql/v1alpha1/template.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\x1a\x18nebius/annotations.proto\"\xe7\x01\n\x07\x43luster\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12G\n\x04spec\x18\x02 \x01(\x0b\x32+.nebius.msp.postgresql.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12K\n\x06status\x18\x03 \x01(\x0b\x32-.nebius.msp.postgresql.v1alpha1.ClusterStatusB\x04\xbaJ\x01\x05R\x06status\"\x91\x02\n\x16\x43onnectionPoolerConfig\x12\x65\n\x0cpooling_mode\x18\x01 \x01(\x0e\x32\x42.nebius.msp.postgresql.v1alpha1.ConnectionPoolerConfig.PoolingModeR\x0bpoolingMode\x12\x33\n\rmax_pool_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\x80\x64(\x05H\x00R\x0bmaxPoolSize\x88\x01\x01\"I\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x42\x10\n\x0e_max_pool_size\"\xd3\x02\n\x0b\x43lusterSpec\x12.\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x0c\xbaH\x05r\x03\x18\x80\x02\xbaJ\x01\x02R\x0b\x64\x65scription\x12)\n\nnetwork_id\x18\x06 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\x12J\n\x06\x63onfig\x18\x03 \x01(\x0b\x32*.nebius.msp.postgresql.v1alpha1.ConfigSpecB\x06\xbaH\x03\xc8\x01\x01R\x06\x63onfig\x12S\n\tbootstrap\x18\x04 \x01(\x0b\x32-.nebius.msp.postgresql.v1alpha1.BootstrapSpecB\x06\xbaH\x03\xc8\x01\x01R\tbootstrap\x12H\n\x06\x62\x61\x63kup\x18\x05 \x01(\x0b\x32*.nebius.msp.postgresql.v1alpha1.BackupSpecB\x04\xbaJ\x01\x02R\x06\x62\x61\x63kup\"\xc1\x02\n\rClusterStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12R\n\x0epreset_details\x18\x04 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.PresetDetailsR\rpresetDetails\x12\\\n\x14\x63onnection_endpoints\x18\x05 \x01(\x0b\x32).nebius.msp.postgresql.v1alpha1.EndpointsR\x13\x63onnectionEndpoints\"\xd3\x01\n\tEndpoints\x12\x32\n\x12private_read_write\x18\x01 \x01(\tB\x04\xbaJ\x01\x05R\x10privateReadWrite\x12\x30\n\x11private_read_only\x18\x02 \x01(\tB\x04\xbaJ\x01\x05R\x0fprivateReadOnly\x12\x30\n\x11public_read_write\x18\x03 \x01(\tB\x04\xbaJ\x01\x05R\x0fpublicReadWrite\x12.\n\x10public_read_only\x18\x04 \x01(\tB\x04\xbaJ\x01\x05R\x0epublicReadOnly\"\x85\x03\n\nConfigSpec\x12$\n\x07version\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x07version\x12[\n\rpooler_config\x18\x02 \x01(\x0b\x32\x36.nebius.msp.postgresql.v1alpha1.ConnectionPoolerConfigR\x0cpoolerConfig\x12m\n\x14postgresql_config_16\x18\x04 \x01(\x0b\x32\x39.nebius.msp.postgresql.v1alpha1.config.PostgresqlConfig16H\x00R\x12postgresqlConfig16\x12#\n\rpublic_access\x18\x05 \x01(\x08R\x0cpublicAccess\x12P\n\x08template\x18\x07 \x01(\x0b\x32,.nebius.msp.postgresql.v1alpha1.TemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x08templateB\x08\n\x06\x63onfigJ\x04\x08\x03\x10\x04\"\x81\x06\n\rBootstrapSpec\x12\xde\x02\n\tuser_name\x18\x01 \x01(\tB\xc0\x02\xbaH\xb8\x02\xba\x01V\n\x14user_name.min_length\x12-User name must be at least 1 characters long.\x1a\x0fsize(this) >= 1\xba\x01R\n\x14user_name.max_length\x12(User name must not exceed 63 characters.\x1a\x10size(this) <= 63\xba\x01\x83\x01\n\x11user_name.pattern\x12@User name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\x1a,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\xc8\x01\x01\xbaJ\x01\x02R\x08userName\x12,\n\ruser_password\x18\x02 \x01(\tB\x07\xbaJ\x01\x04\xc0J\x01R\x0cuserPassword\x12\xe0\x02\n\x07\x64\x62_name\x18\x03 \x01(\tB\xc6\x02\xbaH\xbe\x02\xba\x01X\n\x12\x64\x62_name.min_length\x12\x31\x44\x61tabase name must be at least 1 characters long.\x1a\x0fsize(this) >= 1\xba\x01T\n\x12\x64\x62_name.max_length\x12,Database name must not exceed 63 characters.\x1a\x10size(this) <= 63\xba\x01\x85\x01\n\x0f\x64\x62_name.pattern\x12\x44\x44\x61tabase name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\x1a,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\xc8\x01\x01\xbaJ\x01\x02R\x06\x64\x62Name\"g\n\nBackupSpec\x12.\n\x13\x62\x61\x63kup_window_start\x18\x01 \x01(\tR\x11\x62\x61\x63kupWindowStart\x12)\n\x10retention_policy\x18\x02 \x01(\tR\x0fretentionPolicyBu\n%ai.nebius.pub.msp.postgresql.v1alpha1B\x0c\x43lusterProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.postgresql.v1alpha1B\014ClusterProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1'
  _CLUSTER.fields_by_name['metadata']._options = None
  _CLUSTER.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['spec']._options = None
  _CLUSTER.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['status']._options = None
  _CLUSTER.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _CONNECTIONPOOLERCONFIG.fields_by_name['max_pool_size']._options = None
  _CONNECTIONPOOLERCONFIG.fields_by_name['max_pool_size']._serialized_options = b'\272H\007\"\005\030\200d(\005'
  _CLUSTERSPEC.fields_by_name['description']._options = None
  _CLUSTERSPEC.fields_by_name['description']._serialized_options = b'\272H\005r\003\030\200\002\272J\001\002'
  _CLUSTERSPEC.fields_by_name['network_id']._options = None
  _CLUSTERSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CLUSTERSPEC.fields_by_name['config']._options = None
  _CLUSTERSPEC.fields_by_name['config']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['bootstrap']._options = None
  _CLUSTERSPEC.fields_by_name['bootstrap']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['backup']._options = None
  _CLUSTERSPEC.fields_by_name['backup']._serialized_options = b'\272J\001\002'
  _ENDPOINTS.fields_by_name['private_read_write']._options = None
  _ENDPOINTS.fields_by_name['private_read_write']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['private_read_only']._options = None
  _ENDPOINTS.fields_by_name['private_read_only']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['public_read_write']._options = None
  _ENDPOINTS.fields_by_name['public_read_write']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['public_read_only']._options = None
  _ENDPOINTS.fields_by_name['public_read_only']._serialized_options = b'\272J\001\005'
  _CONFIGSPEC.fields_by_name['version']._options = None
  _CONFIGSPEC.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CONFIGSPEC.fields_by_name['template']._options = None
  _CONFIGSPEC.fields_by_name['template']._serialized_options = b'\272H\003\310\001\001'
  _BOOTSTRAPSPEC.fields_by_name['user_name']._options = None
  _BOOTSTRAPSPEC.fields_by_name['user_name']._serialized_options = b'\272H\270\002\272\001V\n\024user_name.min_length\022-User name must be at least 1 characters long.\032\017size(this) >= 1\272\001R\n\024user_name.max_length\022(User name must not exceed 63 characters.\032\020size(this) <= 63\272\001\203\001\n\021user_name.pattern\022@User name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\032,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\310\001\001\272J\001\002'
  _BOOTSTRAPSPEC.fields_by_name['user_password']._options = None
  _BOOTSTRAPSPEC.fields_by_name['user_password']._serialized_options = b'\272J\001\004\300J\001'
  _BOOTSTRAPSPEC.fields_by_name['db_name']._options = None
  _BOOTSTRAPSPEC.fields_by_name['db_name']._serialized_options = b'\272H\276\002\272\001X\n\022db_name.min_length\0221Database name must be at least 1 characters long.\032\017size(this) >= 1\272\001T\n\022db_name.max_length\022,Database name must not exceed 63 characters.\032\020size(this) <= 63\272\001\205\001\n\017db_name.pattern\022DDatabase name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\032,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\310\001\001\272J\001\002'
  _globals['_CLUSTER']._serialized_start=352
  _globals['_CLUSTER']._serialized_end=583
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=586
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=859
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_start=768
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_end=841
  _globals['_CLUSTERSPEC']._serialized_start=862
  _globals['_CLUSTERSPEC']._serialized_end=1201
  _globals['_CLUSTERSTATUS']._serialized_start=1204
  _globals['_CLUSTERSTATUS']._serialized_end=1525
  _globals['_ENDPOINTS']._serialized_start=1528
  _globals['_ENDPOINTS']._serialized_end=1739
  _globals['_CONFIGSPEC']._serialized_start=1742
  _globals['_CONFIGSPEC']._serialized_end=2131
  _globals['_BOOTSTRAPSPEC']._serialized_start=2134
  _globals['_BOOTSTRAPSPEC']._serialized_end=2903
  _globals['_BACKUPSPEC']._serialized_start=2905
  _globals['_BACKUPSPEC']._serialized_end=3008
# @@protoc_insertion_point(module_scope)
