# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import auth_public_key_pb2 as nebius_dot_iam_dot_v1_dot_auth__public__key__pb2
from nebius.api.nebius.iam.v1 import auth_public_key_service_pb2 as nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2


class AuthPublicKeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Create',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Get',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/List',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
                )
        self.ListByAccount = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/ListByAccount',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Update',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Activate = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Activate',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Deactivate',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class AuthPublicKeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthPublicKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.SerializeToString,
            ),
            'ListByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ListByAccount,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.AuthPublicKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthPublicKeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Create',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Get',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/List',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/ListByAccount',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Update',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Activate',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Deactivate',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Delete',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
