# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/calculator_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.billing.v1alpha1 import calculator_pb2 as nebius_dot_billing_dot_v1alpha1_dot_calculator__pb2
from nebius.api.nebius.billing.v1alpha1 import offer_type_pb2 as nebius_dot_billing_dot_v1alpha1_dot_offer__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0nebius/billing/v1alpha1/calculator_service.proto\x12\x17nebius.billing.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a(nebius/billing/v1alpha1/calculator.proto\x1a(nebius/billing/v1alpha1/offer_type.proto\"\xaa\x01\n\x0f\x45stimateRequest\x12R\n\rresource_spec\x18\x01 \x01(\x0b\x32%.nebius.billing.v1alpha1.ResourceSpecB\x06\xbaH\x03\xc8\x01\x01R\x0cresourceSpec\x12\x43\n\x0boffer_types\x18\n \x03(\x0e\x32\".nebius.billing.v1alpha1.OfferTypeR\nofferTypes\"\xae\x01\n\x10\x45stimateResponse\x12K\n\x0bhourly_cost\x18\n \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\nhourlyCost\x12M\n\x0cmonthly_cost\x18\x14 \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\x0bmonthlyCost\"\xb1\x01\n\x14\x45stimateBatchRequest\x12T\n\x0eresource_specs\x18\x01 \x03(\x0b\x32%.nebius.billing.v1alpha1.ResourceSpecB\x06\xbaH\x03\xc8\x01\x01R\rresourceSpecs\x12\x43\n\x0boffer_types\x18\n \x03(\x0e\x32\".nebius.billing.v1alpha1.OfferTypeR\nofferTypes\"\xb3\x01\n\x15\x45stimateBatchResponse\x12K\n\x0bhourly_cost\x18\n \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\nhourlyCost\x12M\n\x0cmonthly_cost\x18\x14 \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\x0bmonthlyCost2\x8a\x02\n\x11\x43\x61lculatorService\x12_\n\x08\x45stimate\x12(.nebius.billing.v1alpha1.EstimateRequest\x1a).nebius.billing.v1alpha1.EstimateResponse\x12n\n\rEstimateBatch\x12-.nebius.billing.v1alpha1.EstimateBatchRequest\x1a..nebius.billing.v1alpha1.EstimateBatchResponse\x1a$\xbaJ!api.calculator.billing-data-planeBq\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x16\x43\x61lculatorServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.calculator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\026CalculatorServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _ESTIMATEREQUEST.fields_by_name['resource_spec']._options = None
  _ESTIMATEREQUEST.fields_by_name['resource_spec']._serialized_options = b'\272H\003\310\001\001'
  _ESTIMATEBATCHREQUEST.fields_by_name['resource_specs']._options = None
  _ESTIMATEBATCHREQUEST.fields_by_name['resource_specs']._serialized_options = b'\272H\003\310\001\001'
  _CALCULATORSERVICE._options = None
  _CALCULATORSERVICE._serialized_options = b'\272J!api.calculator.billing-data-plane'
  _globals['_ESTIMATEREQUEST']._serialized_start=217
  _globals['_ESTIMATEREQUEST']._serialized_end=387
  _globals['_ESTIMATERESPONSE']._serialized_start=390
  _globals['_ESTIMATERESPONSE']._serialized_end=564
  _globals['_ESTIMATEBATCHREQUEST']._serialized_start=567
  _globals['_ESTIMATEBATCHREQUEST']._serialized_end=744
  _globals['_ESTIMATEBATCHRESPONSE']._serialized_start=747
  _globals['_ESTIMATEBATCHRESPONSE']._serialized_end=926
  _globals['_CALCULATORSERVICE']._serialized_start=929
  _globals['_CALCULATORSERVICE']._serialized_end=1195
# @@protoc_insertion_point(module_scope)
