# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.audit.v2 import audit_event_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/audit/v2/audit_event_service.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a!nebius/audit/v2/audit_event.proto\"\x91\x02\n\x15ListAuditEventRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\'\n\tpage_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xf4\x03(\x00R\x08pageSize\x12\x38\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x05start\x12\x34\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x03\x65nd\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\x12\x1b\n\x06\x66ilter\x18\x06 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\"s\n\x16ListAuditEventResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.audit.v2.AuditEventR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2v\n\x11\x41uditEventService\x12W\n\x04List\x12&.nebius.audit.v2.ListAuditEventRequest\x1a\'.nebius.audit.v2.ListAuditEventResponse\x1a\x08\xbaJ\x05\x61uditBa\n\x16\x61i.nebius.pub.audit.v2B\x16\x41uditEventServiceProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\026AuditEventServiceProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _LISTAUDITEVENTREQUEST.fields_by_name['parent_id']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['page_size']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\007\"\005\030\364\003(\000'
  _LISTAUDITEVENTREQUEST.fields_by_name['start']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['start']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['end']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['end']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['filter']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['filter']._serialized_options = b'\300J\001'
  _AUDITEVENTSERVICE._options = None
  _AUDITEVENTSERVICE._serialized_options = b'\272J\005audit'
  _globals['_LISTAUDITEVENTREQUEST']._serialized_start=186
  _globals['_LISTAUDITEVENTREQUEST']._serialized_end=459
  _globals['_LISTAUDITEVENTRESPONSE']._serialized_start=461
  _globals['_LISTAUDITEVENTRESPONSE']._serialized_end=576
  _globals['_AUDITEVENTSERVICE']._serialized_start=578
  _globals['_AUDITEVENTSERVICE']._serialized_end=696
# @@protoc_insertion_point(module_scope)
