# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/network_interface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/compute/v1/network_interface.proto\x12\x11nebius.compute.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\"\xd1\x02\n\x14NetworkInterfaceSpec\x12\'\n\tsubnet_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x08subnetId\x12:\n\x04name\x18\x02 \x01(\tB&\xbaH\x1f\xc8\x01\x01r\x1a\x10\x01\x18<2\x14^[0-9a-z][0-9a-z-]*$\xbaJ\x01\x02R\x04name\x12H\n\nip_address\x18\x03 \x01(\x0b\x32\x1c.nebius.compute.v1.IPAddressB\x0b\xbaH\x03\xc8\x01\x01\xbaJ\x02\x06\x02R\tipAddress\x12T\n\x11public_ip_address\x18\x04 \x01(\x0b\x32\".nebius.compute.v1.PublicIPAddressB\x04\xbaJ\x01\x06R\x0fpublicIpAddress\x12\x34\n\x07\x61liases\x18\x06 \x03(\x0b\x32\x1a.nebius.compute.v1.IPAliasR\x07\x61liases\"0\n\tIPAddress\x12#\n\rallocation_id\x18\x01 \x01(\tR\x0c\x61llocationId\"^\n\x0fPublicIPAddress\x12%\n\rallocation_id\x18\x01 \x01(\tH\x00R\x0c\x61llocationId\x12\x16\n\x06static\x18\x03 \x01(\x08R\x06staticB\x0c\n\nallocation\"6\n\x07IPAlias\x12+\n\rallocation_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0c\x61llocationId\"\xce\x02\n\x16NetworkInterfaceStatus\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x41\n\nip_address\x18\x03 \x01(\x0b\x32\".nebius.compute.v1.IPAddressStatusR\tipAddress\x12T\n\x11public_ip_address\x18\x04 \x01(\x0b\x32(.nebius.compute.v1.PublicIPAddressStatusR\x0fpublicIpAddress\x12<\n\x07\x61liases\x18\x06 \x01(\x0b\x32\".nebius.compute.v1.IPAliasesStatusR\x07\x61liases\x12\x1f\n\x0bmac_address\x18\x07 \x01(\tR\nmacAddress\x12\x12\n\x04\x66qdn\x18\t \x01(\tR\x04\x66qdn\"P\n\x0fIPAddressStatus\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rallocation_id\x18\x02 \x01(\tR\x0c\x61llocationId\"n\n\x15PublicIPAddressStatus\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rallocation_id\x18\x02 \x01(\tR\x0c\x61llocationId\x12\x16\n\x06static\x18\x03 \x01(\x08R\x06static\"\'\n\x0fIPAliasesStatus\x12\x14\n\x05\x63idrs\x18\x02 \x03(\tR\x05\x63idrsBd\n\x18\x61i.nebius.pub.compute.v1B\x15NetworkInterfaceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.network_interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\025NetworkInterfaceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _NETWORKINTERFACESPEC.fields_by_name['name']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['name']._serialized_options = b'\272H\037\310\001\001r\032\020\001\030<2\024^[0-9a-z][0-9a-z-]*$\272J\001\002'
  _NETWORKINTERFACESPEC.fields_by_name['ip_address']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['ip_address']._serialized_options = b'\272H\003\310\001\001\272J\002\006\002'
  _NETWORKINTERFACESPEC.fields_by_name['public_ip_address']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['public_ip_address']._serialized_options = b'\272J\001\006'
  _IPALIAS.fields_by_name['allocation_id']._options = None
  _IPALIAS.fields_by_name['allocation_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_NETWORKINTERFACESPEC']._serialized_start=120
  _globals['_NETWORKINTERFACESPEC']._serialized_end=457
  _globals['_IPADDRESS']._serialized_start=459
  _globals['_IPADDRESS']._serialized_end=507
  _globals['_PUBLICIPADDRESS']._serialized_start=509
  _globals['_PUBLICIPADDRESS']._serialized_end=603
  _globals['_IPALIAS']._serialized_start=605
  _globals['_IPALIAS']._serialized_end=659
  _globals['_NETWORKINTERFACESTATUS']._serialized_start=662
  _globals['_NETWORKINTERFACESTATUS']._serialized_end=996
  _globals['_IPADDRESSSTATUS']._serialized_start=998
  _globals['_IPADDRESSSTATUS']._serialized_end=1078
  _globals['_PUBLICIPADDRESSSTATUS']._serialized_start=1080
  _globals['_PUBLICIPADDRESSSTATUS']._serialized_end=1190
  _globals['_IPALIASESSTATUS']._serialized_start=1192
  _globals['_IPALIASESSTATUS']._serialized_end=1231
# @@protoc_insertion_point(module_scope)
