# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/target_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import target_group_pb2 as nebius_dot_vpc_dot_v1_dot_target__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/vpc/v1/target_group_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a nebius/vpc/v1/target_group.proto\"/\n\x15GetTargetGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xd8\x02\n\x18UpdateTargetGroupRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1.TargetGroupSpecR\x04spec2\xb5\x01\n\x12TargetGroupService\x12G\n\x03Get\x12$.nebius.vpc.v1.GetTargetGroupRequest\x1a\x1a.nebius.vpc.v1.TargetGroup\x12N\n\x06Update\x12\'.nebius.vpc.v1.UpdateTargetGroupRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcB^\n\x14\x61i.nebius.pub.vpc.v1B\x17TargetGroupServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.target_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\027TargetGroupServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETTARGETGROUPREQUEST.fields_by_name['id']._options = None
  _GETTARGETGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATETARGETGROUPREQUEST.fields_by_name['metadata']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _TARGETGROUPSERVICE._options = None
  _TARGETGROUPSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETTARGETGROUPREQUEST']._serialized_start=215
  _globals['_GETTARGETGROUPREQUEST']._serialized_end=262
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_start=265
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_end=609
  _globals['_TARGETGROUPSERVICE']._serialized_start=612
  _globals['_TARGETGROUPSERVICE']._serialized_end=793
# @@protoc_insertion_point(module_scope)
