# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/serverless/v1alpha1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/msp/serverless/v1alpha1/endpoint.proto\x12\x1enebius.msp.serverless.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a!nebius/msp/v1alpha1/cluster.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"\xea\x01\n\x08\x45ndpoint\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.msp.serverless.v1alpha1.EndpointSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12L\n\x06status\x18\x03 \x01(\x0b\x32..nebius.msp.serverless.v1alpha1.EndpointStatusB\x04\xbaJ\x01\x05R\x06status\"\xa2\x02\n\x0c\x45ndpointSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12)\n\nnetwork_id\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\x12)\n\x08username\x18\x03 \x01(\tB\r\xbaH\x03\xc8\x01\x01\xbaJ\x01\x04\xc0J\x01R\x08username\x12)\n\x08password\x18\x04 \x01(\tB\r\xbaH\x03\xc8\x01\x01\xbaJ\x01\x04\xc0J\x01R\x08password\x12\x1a\n\x04port\x18\x05 \x01(\rB\x06\xbaH\x03\xc8\x01\x01R\x04port\x12S\n\tcontainer\x18\x65 \x01(\x0b\x32\x35.nebius.msp.serverless.v1alpha1.EndpointContainerSpecR\tcontainer\"\xf4\x04\n\x15\x45ndpointContainerSpec\x12\x1c\n\x05image\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05image\x12#\n\rreplica_count\x18\x02 \x01(\x03R\x0creplicaCount\x12X\n\x08template\x18\x03 \x01(\x0b\x32\x34.nebius.msp.serverless.v1alpha1.EndpointTemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x08template\x12\x18\n\x07\x63ommand\x18\x65 \x01(\tR\x07\x63ommand\x12\x12\n\x04\x61rgs\x18\x66 \x03(\tR\x04\x61rgs\x12S\n\x04\x65nvs\x18g \x03(\x0b\x32?.nebius.msp.serverless.v1alpha1.EndpointContainerSpec.EnvsEntryR\x04\x65nvs\x12x\n\x0esensitive_envs\x18h \x03(\x0b\x32H.nebius.msp.serverless.v1alpha1.EndpointContainerSpec.SensitiveEnvsEntryB\x07\xbaJ\x01\x04\xc0J\x01R\rsensitiveEnvs\x12\x46\n\x08liveness\x18\xc9\x01 \x01(\x0b\x32).nebius.msp.serverless.v1alpha1.ProbeSpecR\x08liveness\x1a\x37\n\tEnvsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a@\n\x12SensitiveEnvsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xca\x01\n\tProbeSpec\x12\x1a\n\x04path\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04path\x12#\n\rdelay_seconds\x18\x05 \x01(\x03R\x0c\x64\x65laySeconds\x12\x31\n\x0eperiod_seconds\x18\x06 \x01(\x03\x42\n\xbaH\x07\xc8\x01\x01\"\x02 \x00R\rperiodSeconds\x12\x37\n\x11\x66\x61ilure_threshold\x18\x07 \x01(\x03\x42\n\xbaH\x07\xc8\x01\x01\"\x02 \x00R\x10\x66\x61ilureThresholdJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"i\n\x14\x45ndpointTemplateSpec\x12Q\n\tresources\x18\x01 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.ResourcesSpecB\x06\xbaH\x03\xc8\x01\x01R\tresources\"\xb9\x01\n\x0e\x45ndpointStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12\'\n\x0fpublic_endpoint\x18\x03 \x01(\tR\x0epublicEndpointBv\n%ai.nebius.pub.msp.serverless.v1alpha1B\rEndpointProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.serverless.v1alpha1.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.serverless.v1alpha1B\rEndpointProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1'
  _ENDPOINT.fields_by_name['metadata']._options = None
  _ENDPOINT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINT.fields_by_name['spec']._options = None
  _ENDPOINT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINT.fields_by_name['status']._options = None
  _ENDPOINT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _ENDPOINTSPEC.fields_by_name['network_id']._options = None
  _ENDPOINTSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _ENDPOINTSPEC.fields_by_name['username']._options = None
  _ENDPOINTSPEC.fields_by_name['username']._serialized_options = b'\272H\003\310\001\001\272J\001\004\300J\001'
  _ENDPOINTSPEC.fields_by_name['password']._options = None
  _ENDPOINTSPEC.fields_by_name['password']._serialized_options = b'\272H\003\310\001\001\272J\001\004\300J\001'
  _ENDPOINTSPEC.fields_by_name['port']._options = None
  _ENDPOINTSPEC.fields_by_name['port']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTCONTAINERSPEC_ENVSENTRY._options = None
  _ENDPOINTCONTAINERSPEC_ENVSENTRY._serialized_options = b'8\001'
  _ENDPOINTCONTAINERSPEC_SENSITIVEENVSENTRY._options = None
  _ENDPOINTCONTAINERSPEC_SENSITIVEENVSENTRY._serialized_options = b'8\001'
  _ENDPOINTCONTAINERSPEC.fields_by_name['image']._options = None
  _ENDPOINTCONTAINERSPEC.fields_by_name['image']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTCONTAINERSPEC.fields_by_name['template']._options = None
  _ENDPOINTCONTAINERSPEC.fields_by_name['template']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTCONTAINERSPEC.fields_by_name['sensitive_envs']._options = None
  _ENDPOINTCONTAINERSPEC.fields_by_name['sensitive_envs']._serialized_options = b'\272J\001\004\300J\001'
  _PROBESPEC.fields_by_name['path']._options = None
  _PROBESPEC.fields_by_name['path']._serialized_options = b'\272H\003\310\001\001'
  _PROBESPEC.fields_by_name['period_seconds']._options = None
  _PROBESPEC.fields_by_name['period_seconds']._serialized_options = b'\272H\007\310\001\001\"\002 \000'
  _PROBESPEC.fields_by_name['failure_threshold']._options = None
  _PROBESPEC.fields_by_name['failure_threshold']._serialized_options = b'\272H\007\310\001\001\"\002 \000'
  _ENDPOINTTEMPLATESPEC.fields_by_name['resources']._options = None
  _ENDPOINTTEMPLATESPEC.fields_by_name['resources']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ENDPOINT']._serialized_start=250
  _globals['_ENDPOINT']._serialized_end=484
  _globals['_ENDPOINTSPEC']._serialized_start=487
  _globals['_ENDPOINTSPEC']._serialized_end=777
  _globals['_ENDPOINTCONTAINERSPEC']._serialized_start=780
  _globals['_ENDPOINTCONTAINERSPEC']._serialized_end=1408
  _globals['_ENDPOINTCONTAINERSPEC_ENVSENTRY']._serialized_start=1287
  _globals['_ENDPOINTCONTAINERSPEC_ENVSENTRY']._serialized_end=1342
  _globals['_ENDPOINTCONTAINERSPEC_SENSITIVEENVSENTRY']._serialized_start=1344
  _globals['_ENDPOINTCONTAINERSPEC_SENSITIVEENVSENTRY']._serialized_end=1408
  _globals['_PROBESPEC']._serialized_start=1411
  _globals['_PROBESPEC']._serialized_end=1613
  _globals['_ENDPOINTTEMPLATESPEC']._serialized_start=1615
  _globals['_ENDPOINTTEMPLATESPEC']._serialized_end=1720
  _globals['_ENDPOINTSTATUS']._serialized_start=1723
  _globals['_ENDPOINTSTATUS']._serialized_end=1908
# @@protoc_insertion_point(module_scope)
