# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/access_permit_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import access_permit_pb2 as nebius_dot_iam_dot_v1_dot_access__permit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/iam/v1/access_permit_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a!nebius/iam/v1/access_permit.proto\"\x90\x01\n\x19\x43reateAccessPermitRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32\x1f.nebius.iam.v1.AccessPermitSpecR\x04spec\"\x8a\x01\n\x17ListAccessPermitRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"+\n\x19\x44\x65leteAccessPermitRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"(\n\x16GetAccessPermitRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"u\n\x18ListAccessPermitResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.iam.v1.AccessPermitR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xe7\x02\n\x13\x41\x63\x63\x65ssPermitService\x12O\n\x06\x43reate\x12(.nebius.iam.v1.CreateAccessPermitRequest\x1a\x1b.nebius.common.v1.Operation\x12W\n\x04List\x12&.nebius.iam.v1.ListAccessPermitRequest\x1a\'.nebius.iam.v1.ListAccessPermitResponse\x12O\n\x06\x44\x65lete\x12(.nebius.iam.v1.DeleteAccessPermitRequest\x1a\x1b.nebius.common.v1.Operation\x12I\n\x03Get\x12%.nebius.iam.v1.GetAccessPermitRequest\x1a\x1b.nebius.iam.v1.AccessPermit\x1a\n\xbaJ\x07\x63pl.iamB_\n\x14\x61i.nebius.pub.iam.v1B\x18\x41\x63\x63\x65ssPermitServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.access_permit_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\030AccessPermitServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _ACCESSPERMITSERVICE._options = None
  _ACCESSPERMITSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEACCESSPERMITREQUEST']._serialized_start=189
  _globals['_CREATEACCESSPERMITREQUEST']._serialized_end=333
  _globals['_LISTACCESSPERMITREQUEST']._serialized_start=336
  _globals['_LISTACCESSPERMITREQUEST']._serialized_end=474
  _globals['_DELETEACCESSPERMITREQUEST']._serialized_start=476
  _globals['_DELETEACCESSPERMITREQUEST']._serialized_end=519
  _globals['_GETACCESSPERMITREQUEST']._serialized_start=521
  _globals['_GETACCESSPERMITREQUEST']._serialized_end=561
  _globals['_LISTACCESSPERMITRESPONSE']._serialized_start=563
  _globals['_LISTACCESSPERMITRESPONSE']._serialized_end=680
  _globals['_ACCESSPERMITSERVICE']._serialized_start=683
  _globals['_ACCESSPERMITSERVICE']._serialized_end=1042
# @@protoc_insertion_point(module_scope)
