# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/secret.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.mysterybox.v1 import secret_version_pb2 as nebius_dot_mysterybox_dot_v1_dot_secret__version__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/mysterybox/v1/secret.proto\x12\x14nebius.mysterybox.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\x1a)nebius/mysterybox/v1/secret_version.proto\"\xc0\x01\n\x06Secret\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.mysterybox.v1.SecretSpecR\x04spec\x12@\n\x06status\x18\x03 \x01(\x0b\x32\".nebius.mysterybox.v1.SecretStatusB\x04\xbaJ\x01\x05R\x06status\"\xd5\x01\n\nSecretSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x37\n\x12primary_version_id\x18\x03 \x01(\tB\x04\xbaJ\x01\x07H\x00R\x10primaryVersionId\x88\x01\x01\x12U\n\x0esecret_version\x18\x04 \x01(\x0b\x32\'.nebius.mysterybox.v1.SecretVersionSpecB\x05\xbaJ\x02\x04\x02R\rsecretVersionB\x15\n\x13_primary_version_id\"\xb9\x02\n\x0cSecretStatus\x12>\n\x05state\x18\x01 \x01(\x0e\x32(.nebius.mysterybox.v1.SecretStatus.StateR\x05state\x12\x39\n\ndeleted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tdeletedAt\x12\x35\n\x08purge_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07purgeAt\x12/\n\x14\x65\x66\x66\x65\x63tive_kms_key_id\x18\x04 \x01(\tR\x11\x65\x66\x66\x65\x63tiveKmsKeyId\"F\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1a\n\x16SCHEDULED_FOR_DELETION\x10\x02\x42`\n\x1b\x61i.nebius.pub.mysterybox.v1B\x0bSecretProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\013SecretProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _SECRET.fields_by_name['status']._options = None
  _SECRET.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _SECRETSPEC.fields_by_name['primary_version_id']._options = None
  _SECRETSPEC.fields_by_name['primary_version_id']._serialized_options = b'\272J\001\007'
  _SECRETSPEC.fields_by_name['secret_version']._options = None
  _SECRETSPEC.fields_by_name['secret_version']._serialized_options = b'\272J\002\004\002'
  _globals['_SECRET']._serialized_start=195
  _globals['_SECRET']._serialized_end=387
  _globals['_SECRETSPEC']._serialized_start=390
  _globals['_SECRETSPEC']._serialized_end=603
  _globals['_SECRETSTATUS']._serialized_start=606
  _globals['_SECRETSTATUS']._serialized_end=919
  _globals['_SECRETSTATUS_STATE']._serialized_start=849
  _globals['_SECRETSTATUS_STATE']._serialized_end=919
# @@protoc_insertion_point(module_scope)
