# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/registry/v1/registry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/registry/v1/registry.proto\x12\x12nebius.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xd2\x01\n\x08Registry\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12<\n\x04spec\x18\x02 \x01(\x0b\x32 .nebius.registry.v1.RegistrySpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12@\n\x06status\x18\x03 \x01(\x0b\x32\".nebius.registry.v1.RegistryStatusB\x04\xbaJ\x01\x05R\x06status\"Y\n\x0cRegistrySpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\'\n\x0cimages_count\x18\x02 \x01(\x05\x42\x04\xbaJ\x01\x05R\x0bimagesCount\"\xd8\x01\n\x0eRegistryStatus\x12>\n\x05state\x18\n \x01(\x0e\x32(.nebius.registry.v1.RegistryStatus.StateR\x05state\x12!\n\x0cimages_count\x18\x0b \x01(\x05R\x0bimagesCount\x12#\n\rregistry_fqdn\x18\x0f \x01(\tR\x0cregistryFqdn\">\n\x05State\x12\x0c\n\x08\x43REATING\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x42^\n\x19\x61i.nebius.pub.registry.v1B\rRegistryProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/registry/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.registry.v1.registry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.registry.v1B\rRegistryProtoP\001Z0github.com/nebius/gosdk/proto/nebius/registry/v1'
  _REGISTRY.fields_by_name['metadata']._options = None
  _REGISTRY.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _REGISTRY.fields_by_name['spec']._options = None
  _REGISTRY.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _REGISTRY.fields_by_name['status']._options = None
  _REGISTRY.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _REGISTRYSPEC.fields_by_name['images_count']._options = None
  _REGISTRYSPEC.fields_by_name['images_count']._serialized_options = b'\272J\001\005'
  _globals['_REGISTRY']._serialized_start=146
  _globals['_REGISTRY']._serialized_end=356
  _globals['_REGISTRYSPEC']._serialized_start=358
  _globals['_REGISTRYSPEC']._serialized_end=447
  _globals['_REGISTRYSTATUS']._serialized_start=450
  _globals['_REGISTRYSTATUS']._serialized_end=666
  _globals['_REGISTRYSTATUS_STATE']._serialized_start=604
  _globals['_REGISTRYSTATUS_STATE']._serialized_end=666
# @@protoc_insertion_point(module_scope)
