# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/token_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/iam/v1/token_service.proto\x12\rnebius.iam.v1\x1a\x18nebius/annotations.proto\"\xdf\x02\n\x14\x45xchangeTokenRequest\x12\x1d\n\ngrant_type\x18\x01 \x01(\tR\tgrantType\x12\x30\n\x14requested_token_type\x18\x02 \x01(\tR\x12requestedTokenType\x12(\n\rsubject_token\x18\x03 \x01(\tB\x03\xc8J\x01R\x0csubjectToken\x12,\n\x12subject_token_type\x18\x04 \x01(\tR\x10subjectTokenType\x12\x16\n\x06scopes\x18\x05 \x03(\tR\x06scopes\x12\x1a\n\x08\x61udience\x18\x06 \x01(\tR\x08\x61udience\x12$\n\x0b\x61\x63tor_token\x18\x07 \x01(\tB\x03\xc8J\x01R\nactorToken\x12(\n\x10\x61\x63tor_token_type\x18\x08 \x01(\tR\x0e\x61\x63torTokenType\x12\x1a\n\x08resource\x18\t \x03(\tR\x08resource\"\xbf\x01\n\x13\x43reateTokenResponse\x12&\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tB\x03\xc8J\x01R\x0b\x61\x63\x63\x65ssToken\x12*\n\x11issued_token_type\x18\x02 \x01(\tR\x0fissuedTokenType\x12\x1d\n\ntoken_type\x18\x03 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x04 \x01(\x03R\texpiresIn\x12\x16\n\x06scopes\x18\x05 \x03(\tR\x06scopesBX\n\x14\x61i.nebius.pub.iam.v1B\x11TokenServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\021TokenServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _EXCHANGETOKENREQUEST.fields_by_name['subject_token']._options = None
  _EXCHANGETOKENREQUEST.fields_by_name['subject_token']._serialized_options = b'\310J\001'
  _EXCHANGETOKENREQUEST.fields_by_name['actor_token']._options = None
  _EXCHANGETOKENREQUEST.fields_by_name['actor_token']._serialized_options = b'\310J\001'
  _CREATETOKENRESPONSE.fields_by_name['access_token']._options = None
  _CREATETOKENRESPONSE.fields_by_name['access_token']._serialized_options = b'\310J\001'
  _globals['_EXCHANGETOKENREQUEST']._serialized_start=79
  _globals['_EXCHANGETOKENREQUEST']._serialized_end=430
  _globals['_CREATETOKENRESPONSE']._serialized_start=433
  _globals['_CREATETOKENRESPONSE']._serialized_end=624
# @@protoc_insertion_point(module_scope)
