# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1/progress_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nebius/mk8s/v1/progress_data.proto\x12\x0enebius.mk8s.v1\"C\n\x0cProgressData\x12\x33\n\x08problems\x18\x01 \x03(\x0b\x32\x17.nebius.mk8s.v1.ProblemR\x08problems\"9\n\x07Problem\x12\x14\n\x05stage\x18\x01 \x01(\tR\x05stage\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageBZ\n\x15\x61i.nebius.pub.mk8s.v1B\x11ProgressDataProtoP\x01Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1.progress_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025ai.nebius.pub.mk8s.v1B\021ProgressDataProtoP\001Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1'
  _globals['_PROGRESSDATA']._serialized_start=54
  _globals['_PROGRESSDATA']._serialized_end=121
  _globals['_PROBLEM']._serialized_start=123
  _globals['_PROBLEM']._serialized_end=180
# @@protoc_insertion_point(module_scope)
