# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/storage/v1/s3_events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/storage/v1/s3_events.proto\x12\x11nebius.storage.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x01\n(CompleteMultipartUploadRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12V\n\x05parts\x18\x03 \x03(\x0b\x32@.nebius.storage.v1.CompleteMultipartUploadRequestParameters.PartR\x05parts\x1a;\n\x04Part\x12\x1f\n\x0bpart_number\x18\x01 \x01(\x05R\npartNumber\x12\x12\n\x04\x65tag\x18\x02 \x01(\tR\x04\x65tag\"u\n\x1f\x43ompleteMultipartUploadResponse\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x12\n\x04\x65tag\x18\x03 \x01(\tR\x04\x65tag\"\xe9\x02\n\x1b\x43opyObjectRequestParameters\x12M\n\x06source\x18\x01 \x01(\x0b\x32\x35.nebius.storage.v1.CopyObjectRequestParameters.SourceR\x06source\x12M\n\x06target\x18\x02 \x01(\x0b\x32\x35.nebius.storage.v1.CopyObjectRequestParameters.TargetR\x06target\x1a\x62\n\x06Source\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x1aH\n\x06Target\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\"i\n\x12\x43opyObjectResponse\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12?\n\rlast_modified\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\"y\n\x1d\x44\x65leteObjectRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\";\n\x14\x44\x65leteObjectResponse\x12#\n\rdelete_marker\x18\x01 \x01(\x08R\x0c\x64\x65leteMarker\"\xd1\x01\n\x1e\x44\x65leteObjectsRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12U\n\x07objects\x18\x04 \x03(\x0b\x32;.nebius.storage.v1.DeleteObjectsRequestParameters.ObjectKeyR\x07objects\x1a\x37\n\tObjectKey\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\"\x9c\x03\n\x15\x44\x65leteObjectsResponse\x12P\n\x07\x64\x65leted\x18\x01 \x03(\x0b\x32\x36.nebius.storage.v1.DeleteObjectsResponse.DeleteSuccessR\x07\x64\x65leted\x12L\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x34.nebius.storage.v1.DeleteObjectsResponse.DeleteErrorR\x06\x65rrors\x1am\n\rDeleteSuccess\x12#\n\rdelete_marker\x18\x01 \x01(\x08R\x0c\x64\x65leteMarker\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x1at\n\x0b\x44\x65leteError\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1d\n\nobject_key\x18\x03 \x01(\tR\tobjectKey\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"s\n\x17ObjectRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\"\x7f\n\x0eObjectResponse\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12?\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\"\xdd\x01\n#ListObjectVersionsRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x16\n\x06prefix\x18\x02 \x01(\tR\x06prefix\x12\x1d\n\nkey_marker\x18\x03 \x01(\tR\tkeyMarker\x12*\n\x11version_id_marker\x18\x04 \x01(\x05R\x0fversionIdMarker\x12\x14\n\x05limit\x18\x05 \x01(\x05R\x05limit\x12\x1c\n\tdelimiter\x18\x06 \x01(\tR\tdelimiter\"\x9e\x06\n\x1aListObjectVersionsResponse\x12U\n\x08versions\x18\x01 \x03(\x0b\x32\x39.nebius.storage.v1.ListObjectVersionsResponse.VersionViewR\x08versions\x12\x65\n\x0e\x64\x65lete_markers\x18\x02 \x03(\x0b\x32>.nebius.storage.v1.ListObjectVersionsResponse.DeleteMarkerViewR\rdeleteMarkers\x12\'\n\x0f\x63ommon_prefixes\x18\x03 \x03(\tR\x0e\x63ommonPrefixes\x12\x1c\n\ttruncated\x18\x04 \x01(\x08R\ttruncated\x12&\n\x0fnext_key_marker\x18\x05 \x01(\tR\rnextKeyMarker\x12\x33\n\x16next_version_id_marker\x18\x06 \x01(\x05R\x13nextVersionIdMarker\x1a\xf1\x01\n\x0bVersionView\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x16\n\x06latest\x18\x02 \x01(\x08R\x06latest\x12\x1d\n\nobject_key\x18\x03 \x01(\tR\tobjectKey\x12?\n\rlast_modified\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\x12\x12\n\x04size\x18\x05 \x01(\x03R\x04size\x12\x1d\n\nversion_id\x18\x06 \x01(\tR\tversionId\x12#\n\rstorage_class\x18\x07 \x01(\tR\x0cstorageClass\x1a\xa9\x01\n\x10\x44\x65leteMarkerView\x12\x16\n\x06latest\x18\x01 \x01(\x08R\x06latest\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12?\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\x12\x1d\n\nversion_id\x18\x04 \x01(\tR\tversionId\"\xac\x01\n\x1cListObjectsRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x16\n\x06prefix\x18\x02 \x01(\tR\x06prefix\x12\x1c\n\tdelimiter\x18\x03 \x01(\tR\tdelimiter\x12\x1f\n\x0bstart_after\x18\x04 \x01(\tR\nstartAfter\x12\x14\n\x05limit\x18\x05 \x01(\x05R\x05limit\"\xe5\x02\n\x13ListObjectsResponse\x12K\n\x07objects\x18\x01 \x03(\x0b\x32\x31.nebius.storage.v1.ListObjectsResponse.ObjectViewR\x07objects\x12\'\n\x0f\x63ommon_prefixes\x18\x02 \x03(\tR\x0e\x63ommonPrefixes\x12\x1c\n\ttruncated\x18\x03 \x01(\x08R\ttruncated\x1a\xb9\x01\n\nObjectView\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12?\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\x12\x12\n\x04size\x18\x04 \x01(\x03R\x04size\x12#\n\rstorage_class\x18\x05 \x01(\tR\x0cstorageClass\"q\n\x1bPostObjectRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x12\n\x04size\x18\x03 \x01(\x03R\x04size\"B\n\x12PostObjectResponse\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\"\xb8\x01\n\x1aPutObjectRequestParameters\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\x12\x1d\n\nobject_key\x18\x02 \x01(\tR\tobjectKey\x12\x12\n\x04size\x18\x03 \x01(\x03R\x04size\x12#\n\rstorage_class\x18\x04 \x01(\tR\x0cstorageClass\x12!\n\x0c\x65xpected_md5\x18\x05 \x01(\tR\x0b\x65xpectedMd5\"A\n\x11PutObjectResponse\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x18\n\x07version\x18\x02 \x01(\tR\x07versionB\\\n\x18\x61i.nebius.pub.storage.v1B\rS3EventsProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/storage/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.storage.v1.s3_events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.storage.v1B\rS3EventsProtoP\001Z/github.com/nebius/gosdk/proto/nebius/storage/v1'
  _globals['_COMPLETEMULTIPARTUPLOADREQUESTPARAMETERS']._serialized_start=90
  _globals['_COMPLETEMULTIPARTUPLOADREQUESTPARAMETERS']._serialized_end=345
  _globals['_COMPLETEMULTIPARTUPLOADREQUESTPARAMETERS_PART']._serialized_start=286
  _globals['_COMPLETEMULTIPARTUPLOADREQUESTPARAMETERS_PART']._serialized_end=345
  _globals['_COMPLETEMULTIPARTUPLOADRESPONSE']._serialized_start=347
  _globals['_COMPLETEMULTIPARTUPLOADRESPONSE']._serialized_end=464
  _globals['_COPYOBJECTREQUESTPARAMETERS']._serialized_start=467
  _globals['_COPYOBJECTREQUESTPARAMETERS']._serialized_end=828
  _globals['_COPYOBJECTREQUESTPARAMETERS_SOURCE']._serialized_start=656
  _globals['_COPYOBJECTREQUESTPARAMETERS_SOURCE']._serialized_end=754
  _globals['_COPYOBJECTREQUESTPARAMETERS_TARGET']._serialized_start=756
  _globals['_COPYOBJECTREQUESTPARAMETERS_TARGET']._serialized_end=828
  _globals['_COPYOBJECTRESPONSE']._serialized_start=830
  _globals['_COPYOBJECTRESPONSE']._serialized_end=935
  _globals['_DELETEOBJECTREQUESTPARAMETERS']._serialized_start=937
  _globals['_DELETEOBJECTREQUESTPARAMETERS']._serialized_end=1058
  _globals['_DELETEOBJECTRESPONSE']._serialized_start=1060
  _globals['_DELETEOBJECTRESPONSE']._serialized_end=1119
  _globals['_DELETEOBJECTSREQUESTPARAMETERS']._serialized_start=1122
  _globals['_DELETEOBJECTSREQUESTPARAMETERS']._serialized_end=1331
  _globals['_DELETEOBJECTSREQUESTPARAMETERS_OBJECTKEY']._serialized_start=1276
  _globals['_DELETEOBJECTSREQUESTPARAMETERS_OBJECTKEY']._serialized_end=1331
  _globals['_DELETEOBJECTSRESPONSE']._serialized_start=1334
  _globals['_DELETEOBJECTSRESPONSE']._serialized_end=1746
  _globals['_DELETEOBJECTSRESPONSE_DELETESUCCESS']._serialized_start=1519
  _globals['_DELETEOBJECTSRESPONSE_DELETESUCCESS']._serialized_end=1628
  _globals['_DELETEOBJECTSRESPONSE_DELETEERROR']._serialized_start=1630
  _globals['_DELETEOBJECTSRESPONSE_DELETEERROR']._serialized_end=1746
  _globals['_OBJECTREQUESTPARAMETERS']._serialized_start=1748
  _globals['_OBJECTREQUESTPARAMETERS']._serialized_end=1863
  _globals['_OBJECTRESPONSE']._serialized_start=1865
  _globals['_OBJECTRESPONSE']._serialized_end=1992
  _globals['_LISTOBJECTVERSIONSREQUESTPARAMETERS']._serialized_start=1995
  _globals['_LISTOBJECTVERSIONSREQUESTPARAMETERS']._serialized_end=2216
  _globals['_LISTOBJECTVERSIONSRESPONSE']._serialized_start=2219
  _globals['_LISTOBJECTVERSIONSRESPONSE']._serialized_end=3017
  _globals['_LISTOBJECTVERSIONSRESPONSE_VERSIONVIEW']._serialized_start=2604
  _globals['_LISTOBJECTVERSIONSRESPONSE_VERSIONVIEW']._serialized_end=2845
  _globals['_LISTOBJECTVERSIONSRESPONSE_DELETEMARKERVIEW']._serialized_start=2848
  _globals['_LISTOBJECTVERSIONSRESPONSE_DELETEMARKERVIEW']._serialized_end=3017
  _globals['_LISTOBJECTSREQUESTPARAMETERS']._serialized_start=3020
  _globals['_LISTOBJECTSREQUESTPARAMETERS']._serialized_end=3192
  _globals['_LISTOBJECTSRESPONSE']._serialized_start=3195
  _globals['_LISTOBJECTSRESPONSE']._serialized_end=3552
  _globals['_LISTOBJECTSRESPONSE_OBJECTVIEW']._serialized_start=3367
  _globals['_LISTOBJECTSRESPONSE_OBJECTVIEW']._serialized_end=3552
  _globals['_POSTOBJECTREQUESTPARAMETERS']._serialized_start=3554
  _globals['_POSTOBJECTREQUESTPARAMETERS']._serialized_end=3667
  _globals['_POSTOBJECTRESPONSE']._serialized_start=3669
  _globals['_POSTOBJECTRESPONSE']._serialized_end=3735
  _globals['_PUTOBJECTREQUESTPARAMETERS']._serialized_start=3738
  _globals['_PUTOBJECTREQUESTPARAMETERS']._serialized_end=3922
  _globals['_PUTOBJECTRESPONSE']._serialized_start=3924
  _globals['_PUTOBJECTRESPONSE']._serialized_end=3989
# @@protoc_insertion_point(module_scope)
